<!--
  This is the default template to import a DOCX document as PSML.

  @author Christophe Lauret
  @version 18 February 2013
  
  Current functionalities:
  
  1) Default options:
      a) Default Character Style: used to define all character styles that are not set
      b) Default Paragraph Style: used to define all paragraph styles that are not set
      
  2) Fragments/Sections - create bookmarks for each fragment
  
  3) 
-->
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas"
  xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
  xmlns:v="urn:schemas-microsoft-com:vml"
  xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing"
  xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
  xmlns:w10="urn:schemas-microsoft-com:office:word"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
  xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml"
  xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup"
  xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk"
  xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
  xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape"
  xmlns:ct="http://schemas.openxmlformats.org/package/2006/content-types"
  xmlns:fn="http://www.pageseeder.com/function" exclude-result-prefixes="#all">

  <xsl:output method="xml" indent="no" />
  <xsl:strip-space elements="root section body" />
    <!-- currently only support one footer for a document -->


  <xsl:param name="take-style-from-type-attribute" select="'true'" />
  <xsl:param name="hardcode-bold-and-italic" select="'false'" />
  <xsl:param name="generate-continuation" select="'true'" />
  <xsl:param name="resourcefolder" />
  <xsl:param name="header-text" />
  <xsl:param name="stylemapping" />
  <xsl:param name="imagemapping" />

  <xsl:param name="default-style" select="'Normal'" />
  <xsl:param name="default-table-style" select="'TableNormal'" />
  <xsl:variable name="TableWidthDxa" select="10000" />

  <xsl:include href="export/document.xsl" />
  <xsl:include href="export/footer.xsl" />
  <xsl:include href="export/header.xsl" />
  <xsl:include href="export/numbering.xsl" />
  <xsl:include href="export/content_types.xsl" />
  <xsl:include href="export/apply-styles.xsl" />
  <xsl:include href="export/functions.xsl" />
  <xsl:include href="export/tables.xsl" />
  <xsl:include href="export/images.xsl" />
  <xsl:include href="export/links.xsl" />
  <xsl:include href="export/lists.xsl" />
  <xsl:include href="export/paragraphs.xsl" />
  <xsl:include href="export/formatting.xsl" />
  <xsl:include href="export/styles.xsl" />
  <xsl:include href="export/toc.xsl" />
  
<!-- Root folder -->
  <xsl:strip-space elements="*" />

<!-- The root folder where the DOCX files will be created -->
<xsl:param name="_outputfolder" />

<!-- The root folder containing the Word Template files -->
<xsl:param name="_dotxfolder"/>

<!-- The name of the DOCX file to create -->
<xsl:param name="_docxfilename"/>

  <xsl:param name="_configfileurl"/>
  
<xsl:variable name="_contenttypestemplate" select="concat($_dotxfolder,encode-for-uri('[Content_Types].xml'))"/>

<xsl:variable name="_documentrelationship" select="concat($_dotxfolder,encode-for-uri('word/_rels/document.xml.rels'))"/>
                                                
<xsl:variable name="filename" select="substring-before($_docxfilename,'.docx')" />

  <xsl:variable name="numberingTemplate">
    <xsl:value-of
      select="document($_contenttypestemplate)/ct:Types/ct:Override[fn:string-after-last-delimiter(@ContentType,'\.') = 'numbering+xml']/@PartName" />
  </xsl:variable>

  <xsl:variable name="stylesTemplate">
    <xsl:value-of
      select="document($_contenttypestemplate)/ct:Types/ct:Override[fn:string-after-last-delimiter(@ContentType,'\.') = 'styles+xml']/@PartName" />
  </xsl:variable>
  
  
  <xsl:variable name="configDoc" select="document($_configfileurl)" />
  
    <xsl:variable name="inlinelabels" as="element()">
    <inlinelabels>
    <xsl:choose>
      <xsl:when test="$configDoc/config/inline[@default = 'generate-ps-style']">
        <xsl:for-each select="document//inline">
          <xsl:choose>
            <xsl:when test="$configDoc/config/inline/label[@name = current()/@label]">

            </xsl:when>
            <xsl:when test="@label[not(following::inline/@label = current()/@label)]">
              <label name="{@label}"/>
            </xsl:when>
          </xsl:choose>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
    </inlinelabels>
  </xsl:variable>
  
  <xsl:variable name="blocklabels" as="element()">
    <blocklabels>
     <xsl:choose>
      <xsl:when test="$configDoc/config/block[@default = 'generate-ps-style']">
        <xsl:for-each select="document//block">
          <xsl:choose>
            <xsl:when test="$configDoc/config/block/label[@name = current()/@label]">
            </xsl:when>
            <xsl:when test="@label[not(following::block/@label = current()/@label)]">
              <label name="{@label}"/>
            </xsl:when>
          </xsl:choose>
        </xsl:for-each>
     </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
    </blocklabels>
  </xsl:variable>

  <xsl:variable name="allLists">
     <xsl:copy-of
       select="//*[name()='list' or name()='nlist'][not(ancestor::list or ancestor::nlist)]" />
   </xsl:variable>
 
   <xsl:variable name="numAllLists">
     <xsl:value-of select="count($allLists/*)" />
   </xsl:variable>
 
   
  
<!-- [content_types].xml ====================================================================== -->

<xsl:output method="xml" version="1.0" indent="no" encoding="UTF-8" standalone="yes"/>


<!--
  The root node of the psml file
-->

<xsl:template match="/">
  <xsl:variable name="maincontext" select="current()"/>
  
  <xsl:call-template name="create-documents"/>
  
      <!-- create images map file -->
<!--       <xsl:call-template name="create-image-mapping"/> -->
      <!-- ok do the rest now -->
    <xsl:apply-templates mode="content"/>
  </xsl:template>


<xsl:template match="* | @*" mode="copy">
   <xsl:copy><xsl:copy-of select="@*"/><xsl:apply-templates mode="copy"/></xsl:copy>
</xsl:template>
   
</xsl:stylesheet>
