<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
    xmlns:fn="http://www.pageseeder.com/function" exclude-result-prefixes="#all">
    
  <xsl:template name="apply-style">
    <xsl:variable name="stylename">
      <xsl:choose>
        <xsl:when test="name()='toc'">
          <xsl:choose>
            <xsl:when test="$configDoc/config/toc[@style != '']">
              <xsl:value-of select="$configDoc/config/toc/@style"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$configDoc/config/defaultparagraphstyle/@style"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        
        <xsl:when test="name()='para' and parent::block">
          <xsl:choose>
            <xsl:when test="parent::block/@label = $configDoc/config/block/label[@style='generate-ps-style']/@name">
              <xsl:value-of select="concat('psblock',parent::block/@label)"/>
            </xsl:when>
            <xsl:when test="parent::block/@label = $configDoc/config/block/label[@style!='']/@name">
              <xsl:value-of select="$configDoc/config/block/label[@name = parent::block/@label]/@style"/>
            </xsl:when>
            <xsl:when test="$configDoc/config/block/@default = 'generate-ps-style'">
              <xsl:value-of select="concat('psblock',parent::block/@label)"/>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="name()='para'">
          <xsl:value-of select="$configDoc/config/defaultparagraphstyle/@style"/>
        </xsl:when>
        <xsl:when test="name()='br'">
          <xsl:value-of select="$configDoc/config/defaultparagraphstyle/@style"/>
        </xsl:when>
       
        <xsl:when test="ancestor::inline">
          <xsl:choose>
            <xsl:when test="ancestor::inline/@label = $configDoc/config/inline/label[@style='generate-ps-style']/@name">
              <xsl:value-of select="concat('psinline',ancestor::inline[1]/@label)"/>
            </xsl:when>
            <xsl:when test="ancestor::inline/@label = $configDoc/config/inline/label[@style!='']/@name">
              <xsl:variable name="name"><xsl:value-of select="ancestor::inline[1]/@label"/></xsl:variable>
              <xsl:value-of select="$configDoc/config/inline/label[@name = $name]/@style"/>
            </xsl:when>
            <xsl:when test="$configDoc/config/inline/@default = 'generate-ps-style'">
              <xsl:value-of select="concat('psinline',ancestor::inline[1]/@label)"/>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="name() = 'inline'">
          <xsl:choose>
            <xsl:when test="ancestor::inline/@label = $configDoc/config/inline/label[@style='generate-ps-style']/@name">
              <xsl:value-of select="concat('psinline',ancestor::inline[1]/@label)"/>
            </xsl:when>
            <xsl:when test="ancestor::inline/@label = $configDoc/config/inline/label[@style!='']/@name">
              <xsl:variable name="name"><xsl:value-of select="ancestor::inline[1]/@label"/></xsl:variable>
              <xsl:value-of select="$configDoc/config/inline/label[@name = $name]/@style"/>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="name()='block'">
          <xsl:choose>
            <xsl:when test="@label = $configDoc/config/block/label[@style='generate-ps-style']/@name">
              <xsl:value-of select="concat('psblock',@label)"/>
            </xsl:when>
            <xsl:when test="@label = $configDoc/config/block/label[@style!='']/@name">
              <xsl:value-of select="$configDoc/config/block/label[@name = current()/@label]/@style"/>
            </xsl:when>
            
            <xsl:otherwise>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="name()='heading'">
          <xsl:choose>
            <xsl:when test="$configDoc/config/heading/style[@level = current()/@level]">  
              <xsl:value-of select="$configDoc/config/heading/style[@level = current()/@level]/@name"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$configDoc/config/defaultparagraphstyle/@style"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="name()='title'">
          <xsl:choose>
            <xsl:when test="$configDoc/config/title[@name != '']">  
              <xsl:value-of select="$configDoc/config/title/@name"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$configDoc/config/defaultparagraphstyle/@style"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:when test="ancestor::item">
          <xsl:value-of select="'List Paragraph'"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="if (self::text() and ancestor::monospace) then 'monospace'
		                       else name()"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="allStyles" select="document(concat($_dotxfolder,$stylesTemplate))" />

    <xsl:choose>
      <xsl:when test="fn:elementType(name())='para'" >
        <w:pStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$configDoc/config/defaultparagraphstyle/@style]]/@w:styleId}"/>
      </xsl:when>
      <xsl:when test="fn:elementType(name())='br'" >
        <w:pStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$configDoc/config/defaultparagraphstyle/@style]]/@w:styleId}"/>
      </xsl:when>
	    <xsl:when test="fn:elementType(name())='block' and $allStyles/w:styles/w:style/w:name[@w:val=$stylename]" >
        <w:pStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$stylename]]/@w:styleId}"/>
      </xsl:when>
      <xsl:when test="fn:elementType(name())='block' and $stylename != ''" >
        <w:pStyle w:val="{$stylename}"/>
      </xsl:when>
      <xsl:when test="fn:elementType(name())='block'" >
        <w:pStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$configDoc/config/defaultparagraphstyle/@style]]/@w:styleId}"/>
      </xsl:when>
      
      <xsl:when test="fn:elementType(name())='inline' and $allStyles/w:styles/w:style[w:name[@w:val=$stylename]]/@w:styleId">
        <w:rStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$stylename]]/@w:styleId}"/>
      </xsl:when>
      <xsl:when test="fn:elementType(name())='inline' and $stylename != ''">
        <w:rStyle w:val="{$stylename}"/>
      </xsl:when>
	    <xsl:when test="fn:elementType(name())='inline'">
        <w:rStyle w:val="{$allStyles/w:styles/w:style[w:name[@w:val=$configDoc/config/defaultcharacterstyle/@style]]/@w:styleId}"/>
      </xsl:when>
	    <xsl:when test="fn:elementType(name())='table' and $allStyles/w:styles/w:style[w:name[@w:val=$stylename]]/@w:styleId">
        <w:tblStyle w:val="{$configDoc/config/table/@default}"/>
      </xsl:when>
      
    </xsl:choose>
  </xsl:template>
    
</xsl:stylesheet>