<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
  xmlns:v="urn:schemas-microsoft-com:vml"
  xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
  xmlns:w10="urn:schemas-microsoft-com:office:word"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
  xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
  xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
  xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
  xmlns:fn="http://www.pageseeder.com/function" xmlns:dec="java:java.net.URLDecoder" exclude-result-prefixes="#all">
  
  <xsl:template match="text()" mode="content">
      <!-- no mixed content, create a run instead -->
    <xsl:choose>
      <xsl:when test="parent::displaytitle">
        
      </xsl:when>
      <xsl:when test="parent::fragment">
        <w:p>
          <w:r>
            <w:t xml:space="preserve"><xsl:value-of select="." /></w:t>
          </w:r>
        </w:p>
      </xsl:when>
      <xsl:otherwise>
        <w:r>
          <w:rPr>
           <!--##inlineLabel##-->
            <xsl:if test="ancestor::inline">
                <!-- if parent is an inline -->
              <xsl:choose>
                <xsl:when test="matches(ancestor::inline[1]/@label,$configDoc/config/block/@ignore)">

                </xsl:when>
                <xsl:when
                  test="ancestor::inline[@label]">
                  <xsl:call-template name="apply-style" />
                </xsl:when>
                <xsl:otherwise>
                    <!-- otherwise, inherit style from paragraph -->
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
            <!--##monospace##-->
            <xsl:if test="ancestor::monospace">
              <xsl:call-template name="apply-style" />
            </xsl:if>
            <!--##sup##-->
            <xsl:if test="ancestor::sup">
              <w:vertAlign w:val="superscript" />
            </xsl:if>
            <!--##sub##-->
            <xsl:if test="ancestor::sub">
              <w:vertAlign w:val="subscript" />
            </xsl:if>
            <!--##bold##-->
            <xsl:if test="ancestor::bold">
              <w:b />
            </xsl:if>
            <!--##italic##-->
            <xsl:if test="ancestor::italic ">
              <w:i />
            </xsl:if>
            <!--##underline##-->
            <xsl:if test="ancestor::underline">
              <w:u w:val="single" />
            </xsl:if>
          </w:rPr>
          <w:t xml:space="preserve"><xsl:value-of select="." /></w:t>
        </w:r>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--##code##-->
  <xsl:template match="code" mode="content">
    <w:p>
      <w:pPr>
        <xsl:call-template name="apply-style" />
      </w:pPr>
      <w:r>
        <xsl:variable name="return-char" select="codepoints-to-string(10)" />
        <xsl:for-each select="tokenize(.,$return-char)">
          <xsl:if test="current() !='' ">
            <w:t xml:space="preserve"><xsl:value-of select="current()" /></w:t>
            <w:cr />
          </xsl:if>
        </xsl:for-each>
      </w:r>
    </w:p>
  </xsl:template>

  <!-- inlineLabels -->
  <!--##inlineLabel##-->
  <xsl:template match="inline" mode="content">
    <xsl:variable name="id" select="concat(@label, '-', generate-id())" />
    <xsl:choose>
      <xsl:when test="parent::block and fn:hasBlockElements(parent::block)='true'">
        <w:p>
          <xsl:apply-templates mode="content" />
        </w:p>
      </xsl:when>
      <xsl:otherwise>
       <xsl:apply-templates mode="content" /> 
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--##bold##-->
  <xsl:template match="bold" mode="content">
    <xsl:apply-templates mode="content" />
  </xsl:template>
  
  <!--##underline##-->
  <xsl:template match="underline" mode="content">
    <xsl:apply-templates  mode="content"/>
  </xsl:template>
  
  <!--##sub##-->
  <xsl:template match="sub" mode="content">
    <xsl:apply-templates  mode="content"/>
  </xsl:template>
  
  <!--##sup##-->
  <xsl:template match="sup" mode="content">
    <xsl:apply-templates  mode="content"/>
  </xsl:template>
  
  <!--##italic##-->
  <xsl:template match="italic" mode="content">
    <xsl:apply-templates  mode="content"/>
  </xsl:template>
  
  <!--##monospace##-->
  <xsl:template match="monospace" mode="content">
    <xsl:apply-templates  mode="content"/>
  </xsl:template>
  
  <!--##br##-->
  <xsl:template match="br" mode="content">
    <xsl:choose>
      <xsl:when
        test="preceding-sibling::*[fn:isBlockElement(.)='true'] or following-sibling::*[fn:isBlockElement(.)='true']">
        <w:p>
          <w:pPr>
		        <xsl:call-template name="apply-style" />
		      </w:pPr>
          <w:r>
            <w:br />
          </w:r>
        </w:p>
      </xsl:when>
      <xsl:when test="parent::fragment">
        <w:p>
          <w:r>
            <w:br />
          </w:r>
        </w:p>
      </xsl:when>
      <xsl:otherwise>
        <w:r>
          <w:br />
        </w:r>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>