<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
	xmlns:fn="http://www.pageseeder.com/function" xmlns:dec="java:java.net.URLDecoder"
	exclude-result-prefixes="#all">

	<xsl:function name="fn:elementType">
		<xsl:param name="name" />
		<xsl:choose>
			<xsl:when
				test="$name='para' or $name='item' or $name='block' or $name='code' or $name='blockxref' or $name='heading' or $name='title'">
				<xsl:value-of select="'block'" />
			</xsl:when>
			<xsl:when test="$name='table'">
				<xsl:value-of select="'table'" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'inline'" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>

	<xsl:function name="fn:getNumberingId">
		<xsl:param name="current" as="element()" />
		<xsl:choose>
			<xsl:when
				test="$current/ancestor::*[name() = 'list' or 'nlist']/parent::block and 
              $current/ancestor::*[name() = 'list' or 'nlist']/parent::block/@label = $configDoc/config/lists/list/@name and 
              $configDoc/config/lists/(list|nlist)[@name = $current/ancestor::*[name() = 'list' or 'nlist']/parent::block/@label][@style != '']">
				<xsl:variable name="styleName"
					select="$configDoc/config/lists/(list|nlist)[@name = $current/ancestor::*[name() = 'list' or 'nlist']/parent::block/@label]/@style" />
				<xsl:value-of
					select="document(concat($_dotxfolder,$numberingTemplate))/w:numbering/w:num[w:abstractNumId/@w:val = document(concat($_dotxfolder,$numberingTemplate))/w:numbering/w:abstractNum[w:numStyleLink[@w:val = $styleName]]/@w:abstractNumId]/@w:numId" />
			</xsl:when>
			<xsl:when
				test="$current/ancestor::*[name() = 'list' or 'nlist']/parent::block and 
				      $current/ancestor::*[name() = 'list' or 'nlist']/parent::block/@label = $configDoc/config/lists/(list|nlist)/@name">
				<xsl:variable name="styleName"
					select="$current/ancestor::*[name() = 'list' or 'nlist']/parent::block/@label" />
				<xsl:variable name="maxnumId"
					select="max(document(concat($_dotxfolder,$numberingTemplate))/w:numbering/w:num/number(@w:numId))" />
				<xsl:variable name="position"
					select="count($configDoc/config/lists/(list|nlist)) - count($configDoc/config/lists/(list|nlist)[@name=$styleName]/following-sibling::*[name() = 'list' or 'nlist'][@style=''])" />
				<xsl:value-of select="$maxnumId + $position" />
			</xsl:when>
			<xsl:when test="$current/parent::*[name() = 'nlist']">
			
				<xsl:variable name="maxnumId"
					select="max(document(concat($_dotxfolder,$numberingTemplate))/w:numbering/w:num/number(@w:numId))" />
				<xsl:variable name="defaultPosition"
					select="count($configDoc/config/lists/(list|nlist)) - count($configDoc/config/lists/nlist[@name='default']/following-sibling::*[name() = 'list' or 'nlist'][@style=''])" />
				<xsl:value-of select="$maxnumId + $defaultPosition" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="maxnumId"
					select="max(document(concat($_dotxfolder,$numberingTemplate))/w:numbering/w:num/number(@w:numId))" />
				<xsl:variable name="defaultPosition"
					select="count($configDoc/config/lists/(list|nlist)) - count($configDoc/config/lists/list[@name='default']/following-sibling::*[name() = 'list' or 'nlist'][@style=''])" />
				<xsl:value-of select="$maxnumId + $defaultPosition" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>


	<xsl:function name="fn:hasBlockElements">
		<xsl:param name="element" />
		<xsl:choose>
			<xsl:when
				test="$element/block or $element/para or $element/heading or $element/code or $element/nlist or $element/table or $element/list or $element/blockxref">
				<xsl:value-of select="true()" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>

	<xsl:function name="fn:isBlockElement">
		<xsl:param name="element" />
		<xsl:choose>
			<xsl:when
				test="$element[name()='heading' or contains(name(),'list') or name()='para' or
                                        name()='block' or name()='table' or name()='code' or name()='blockxref']">
				<xsl:value-of select="true()" />
			</xsl:when>

			<xsl:otherwise>
				<xsl:value-of select="false()" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>


	<xsl:function name="fn:string-after-last-delimiter">
		<xsl:param name="string" />
		<xsl:param name="delimiter" />
		<xsl:analyze-string regex="^(.*)[{$delimiter}]([^{$delimiter}]+)"
			select="$string">
			<xsl:matching-substring>
				<xsl:value-of select="regex-group(2)" />
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:function>

	<xsl:function name="fn:decode-keep-slashes">
		<xsl:param name="path" />
<!--     <xsl:value-of -->
<!--       select="string-join(for $i in tokenize($path, '/') return dec:decode($i), '/')" /> -->
	</xsl:function>
</xsl:stylesheet>