<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
  xmlns:v="urn:schemas-microsoft-com:vml"
  xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
  xmlns:w10="urn:schemas-microsoft-com:office:word"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
  xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
  xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
  xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
  xmlns:fn="http://www.pageseeder.com/function" xmlns:dec="java:java.net.URLDecoder" exclude-result-prefixes="#all">
  
    <!-- consolidate xref subdoc is done during publish process -->
  <!--##xref##-->
  <xsl:template match="xref" mode="content">
    <xsl:choose>
      <xsl:when test="@frag != 'default' and @frag != ''">
        <xsl:variable name="internalref" select="concat(@uriid,'-',@frag)" />
        <w:r>
          <w:fldChar w:fldCharType="begin" />
        </w:r>
        <w:r>
          <w:instrText xml:space="preserve"><xsl:text> PAGEREF </xsl:text><xsl:value-of
            select="replace($internalref,'\W','_')" /><xsl:text> \h</xsl:text></w:instrText>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="separate" />
        </w:r>
        <w:r>
          <w:rPr>
            <w:rStyle w:val="Hyperlink"/>
          </w:rPr>
          <w:t>
            <xsl:value-of select="." />
          </w:t>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="end" />
        </w:r>
      </xsl:when>
      <xsl:when test="@frag = 'default'">
        <xsl:variable name="internalref" select="@uriid" />
        <w:r>
          <w:fldChar w:fldCharType="begin" />
        </w:r>
        <w:r>
          <w:instrText xml:space="preserve"><xsl:text> PAGEREF </xsl:text><xsl:value-of
            select="replace($internalref,'\W','_')" /><xsl:text> \h</xsl:text></w:instrText>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="separate" />
        </w:r>
        <w:r>
          <w:rPr>
            <w:rStyle w:val="Hyperlink"/>
            <w:color w:val="0000FF"/>
            <w:u w:val="single"/>
          </w:rPr>
          <w:t>
            <xsl:value-of select="." />
          </w:t>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="end" />
        </w:r>
      </xsl:when>
      <xsl:when test="@href[contains(.,'#')]">
        <xsl:variable name="internalref" select="replace(substring-after(@href,'#'),'\W','_')" />
        <w:r>
          <w:fldChar w:fldCharType="begin" />
        </w:r>
        <w:r>
          <w:instrText xml:space="preserve"><xsl:text> PAGEREF </xsl:text><xsl:value-of
            select="$internalref" /><xsl:text> \h</xsl:text></w:instrText>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="separate" />
        </w:r>
        <w:r>
          <w:rPr>
            <xsl:call-template name="apply-style" />
          </w:rPr>
          <w:t>
            <xsl:value-of select="." />
          </w:t>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="end" />
        </w:r>
      </xsl:when>
      
      <xsl:when test="@href[not(contains(.,'#'))][not(ends-with(.,'.psml'))]">
                <!-- only process internal link-->
        <w:hyperlink w:anchor="{@href}" w:history="1">
          <w:r>
            <w:rPr>
              <xsl:call-template name="apply-style" />

            </w:rPr>
            <w:t xml:space="preserve"><xsl:value-of select="." /></w:t>
          </w:r>
        </w:hyperlink>
      </xsl:when>
      <xsl:when test="@href[not(contains(.,'#'))]">
                <!-- only process internal link-->
          <xsl:variable name="content">
			      <xsl:choose>
			        <xsl:when test="@title!=''">
			          <xsl:value-of select="@title" />
			        </xsl:when>
			        <xsl:otherwise>
			          <xsl:value-of select="@urititle" />
			        </xsl:otherwise>
			      </xsl:choose>
			    </xsl:variable>
			    <w:r>
			      <w:t>
			        <xsl:value-of select="$content" />
			      </w:t>
			    </w:r>
      </xsl:when>
      <xsl:otherwise>
        <w:bookmarkStart w:id="{count(preceding::fragment) + count(ancestor::fragment) +count(preceding::xref) + count(preceding::document) + count(ancestor::document) + count(preceding::link[@name])}"
          w:name="{concat('_a',string(count(preceding::fragment) + count(ancestor::fragment) +count(preceding::xref) + count(preceding::document) + count(ancestor::document) + count(preceding::link[@name])))}" />
        <w:bookmarkEnd w:id="{count(preceding::fragment) + count(ancestor::fragment) +count(preceding::xref) + count(preceding::document) + count(ancestor::document) + count(preceding::link[@name])}" />
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>
  
  <!--##blockXref##-->
  <xsl:template match="blockxref" mode="content">
    <xsl:choose>
      <xsl:when test="document | fragment">
        <xsl:apply-templates  mode="content"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="content"
          select="if (@title != '')  then @title else @urititle" />
        <w:p>
          <w:r>
            <w:rPr>
              <w:rStyle w:val="reference" />
            </w:rPr>
            <w:t>
              <xsl:value-of select="$content" />
            </w:t>
          </w:r>
        </w:p>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

    <!-- link href="some http" -->
    <!-- will create a hyperlink in the document -->
    <!-- currently only support external link -->
    <!-- link href="some http" -->
    <!-- will create a hyperlink in the document -->
  <!--##link##-->
  <xsl:template match="link" mode="content">
    <xsl:choose>
      <xsl:when test="@href[contains(.,'#')]">
        <xsl:variable name="internalref" select="substring-after(@href,'#')" />
        <w:hyperlink w:anchor="{$internalref}" w:history="1">
          <w:r>
            <w:rPr>
              <xsl:call-template name="apply-style" />

            </w:rPr>
            <w:t xml:space="preserve"><xsl:value-of select="." /></w:t>
          </w:r>
        </w:hyperlink>
      </xsl:when>
      <xsl:when test="@href[not(contains(.,'#'))]">
                <!-- only process internal link-->
        <w:r>
          <w:fldChar w:fldCharType="begin" />
        </w:r>
        <w:r>
          <w:instrText xml:space="preserve"><xsl:text> HYPERLINK "</xsl:text><xsl:value-of
            select="@href" /><xsl:text>" </xsl:text></w:instrText>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="separate" />
        </w:r>
        <w:r>
          <w:rPr>
            <xsl:call-template name="apply-style" />
          </w:rPr>
          <w:t>
            <xsl:value-of select="." />
          </w:t>
        </w:r>
        <w:r>
          <w:fldChar w:fldCharType="end" />
        </w:r>
      </xsl:when>
      <xsl:when test="not(@href) and not(@name)">
        <xsl:apply-templates mode="content"/>
      </xsl:when>
      <xsl:when test="@name">
        <w:bookmarkStart w:id="{count(preceding::fragment) + count(ancestor::fragment) +count(preceding::xref) + count(preceding::document) + count(ancestor::document) + count(preceding::link[@name])}"
          w:name="{@name}" />
        <w:bookmarkEnd w:id="{count(preceding::fragment) + count(ancestor::fragment) +count(preceding::xref) + count(preceding::document) + count(ancestor::document) + count(preceding::link[@name])}" />
      
     </xsl:when>
      <xsl:otherwise>
          <xsl:apply-templates mode="content"/>
      
        </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>