<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
  xmlns:o="urn:schemas-microsoft-com:office:office"
  xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
  xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
  xmlns:v="urn:schemas-microsoft-com:vml"
  xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
  xmlns:w10="urn:schemas-microsoft-com:office:word"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
  xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
  xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
  xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
  xmlns:fn="http://www.pageseeder.com/function" xmlns:dec="java:java.net.URLDecoder" exclude-result-prefixes="#all">
  
  
      <!-- Title is imported as normal text, applying the default word heading styles -->
  <!--##title##-->
  <xsl:template match="title" mode="content">
    <w:p>
      <w:pPr>
        <xsl:call-template name="apply-style" />
      </w:pPr>
      <xsl:apply-templates  mode="content"/>
    </w:p>
  </xsl:template>
  
    <!-- Headings are imported as normal text, applying the default word heading styles -->
  <!--##heading##-->
  <xsl:template match="heading" mode="content">
        <!-- Handle headings. Style mapped from element name -->
    <w:p>
      <w:pPr>
        <xsl:call-template name="apply-style" />
      </w:pPr>
      <xsl:apply-templates mode="content" />
    </w:p>
  </xsl:template>

       <!--  A paralabel is imported as a normal paragraph -->
  <!--##paraLabel##-->
  
    
    
  <xsl:template match="block" mode="content">
      <!--
        if paraLabel contains only inline elements or text, create w:p here,
      -->
     
    <xsl:variable name="id" select="concat(@label, '-', generate-id())" />
    <xsl:choose>
        <!-- when containing other block elements, including mixed content -->
        <!-- will not create w:p here -->
      <xsl:when test="matches(@label,$configDoc/config/block/@ignore)">
      </xsl:when> 
        
      <xsl:when test="fn:hasBlockElements(.)='true'">
        <xsl:apply-templates mode="content" />
      </xsl:when>
      <xsl:otherwise>
          <!-- when containing only inline elements or text()-->
        <w:p>
          <w:pPr>
            <xsl:call-template name="apply-style" />
            <!--##list##-->
            <!--##nlist##-->
            <!--##item##--> 
            <xsl:if test="ancestor::item">
              <xsl:choose>
                <xsl:when test="position()=1">
                  <w:numPr>
                  <w:ilvl w:val="{count(ancestor::list)+count(ancestor::nlist)-1}" />
                  <w:numId w:val="{fn:getNumberingId(current())}" />
                </w:numPr>
                </xsl:when>
                <xsl:otherwise>
                  <w:ind w:left="{720*(count(ancestor::list)+count(ancestor::nlist))}" />
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </w:pPr>
          <xsl:apply-templates  mode="content"/>
        </w:p>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- para are treated normally -->
  <!--##para##-->
  <xsl:template match="para" mode="content">
    <w:p>
      <xsl:if test="normalize-space(.)!=''">
        <w:pPr>
          
          <xsl:call-template name="apply-style" />
          <xsl:if test="string(@indent) != '' and @indent castable as xs:integer">
            <w:ind w:left="{720*number(@indent)}" />
          </xsl:if>
          <!--##list##-->
          <!--##nlist##-->
          <!--##item##--> 
          <xsl:if test="ancestor::item">
            <xsl:choose>
              <xsl:when test="position()=1">
                <w:numPr>
		              <w:ilvl w:val="{count(ancestor::list)+count(ancestor::nlist)-1}" />
		              <w:numId w:val="{fn:getNumberingId(current())}" />
		            </w:numPr>
              </xsl:when>
              <xsl:otherwise>
                <w:ind w:left="{720*(count(ancestor::list)+count(ancestor::nlist))}" />
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </w:pPr>
      </xsl:if>
      <xsl:apply-templates  mode="content"/>
    </w:p>
  </xsl:template>
  
  <xsl:template match="property" mode="content">
    <w:p>
      <xsl:apply-templates  mode="content"/>
    </w:p>
  </xsl:template>
  
  <xsl:template match="preformat" mode="content">
    <w:p>
      <xsl:apply-templates  mode="content"/>
    </w:p>
  </xsl:template>
  
</xsl:stylesheet>