<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" exclude-result-prefixes="#all">

  <!--
    Handle tables with colspan and rowspan
    
    @author Hugo Inacio
  -->

  <!-- 1st step to invert columns and rows, normalizing in the process all colspans. -->
	<xsl:template name="firstTasformation">
		<xsl:param name="selection" as="element()" />
		<table>
			<xsl:copy-of select="$selection/@*" />
			<xsl:copy-of select="$selection/*[not(name() = 'row')]" />
			<xsl:for-each select="$selection/row">
				<row>
					<xsl:for-each select="cell|hcell">
						<xsl:choose>
							<xsl:when test="@colspan">
								<xsl:variable name="this" select="." as="element()" />
								<xsl:variable name="thisname" select="$this/name()" />
								<xsl:for-each select="1 to @colspan">
									<xsl:element name="{$thisname}">
										<xsl:attribute name="colspans"><xsl:value-of
											select="generate-id($this)" /></xsl:attribute>
										<xsl:copy-of select="$this/@*" />
										<xsl:copy-of select="$this/node()" />
									</xsl:element>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="." />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</row>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="text()" mode="colspan" />


	<xsl:template match="table" mode="colspan">

	</xsl:template>

  <!-- 2nd step is to normalize all rowspans -->
	<xsl:template name="secondTasformation">
		<xsl:param name="table1" as="element()" />
		<table>
			<xsl:copy-of select="$table1/table/@*" />
			<xsl:copy-of select="$table1/table/*[not(name() = 'row')]" />
			<xsl:copy>
				<xsl:copy-of select="$table1/table/row[1]" />
				<xsl:apply-templates select="$table1/table/row[2]"
					mode="rowspan">
					<xsl:with-param name="previousRow" select="$table1/table/row[1]" />
				</xsl:apply-templates>
			</xsl:copy>
		</table>
	</xsl:template>

	<xsl:template match="row" mode="rowspan">
		<xsl:param name="previousRow" as="element()" />

		<xsl:variable name="currentRow" select="." />

		<xsl:variable name="normalizedCells">
			<xsl:for-each select="$previousRow">
				<xsl:for-each select="hcell|cell">
					<xsl:choose>
						<xsl:when test="@rowspan &gt; 1">
							<xsl:copy>
								<xsl:attribute name="rowspan">
	                            <xsl:value-of select="@rowspan - 1" />
	                        </xsl:attribute>
								<xsl:copy-of select="@*[not(name() = 'rowspan')]" />
								<xsl:copy-of select="node()" />
							</xsl:copy>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of
								select="$currentRow/*[1 + count(current()/preceding-sibling::*[not(@rowspan) or (@rowspan = 1)])]" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="newRow" as="element(row)">
			<xsl:copy>
				<xsl:copy-of select="$currentRow/@*" />
				<xsl:copy-of select="$normalizedCells" />
			</xsl:copy>
		</xsl:variable>

		<xsl:copy-of select="$newRow" />

		<xsl:apply-templates select="following-sibling::row[1]"
			mode="rowspan">
			<xsl:with-param name="previousRow" select="$newRow" />
		</xsl:apply-templates>
	</xsl:template>
  
  <!--##table##-->
	<xsl:template match="table" mode="content">
		<xsl:variable name="table1" as="element()">
			<table1>
				<xsl:call-template name="firstTasformation">
					<xsl:with-param name="selection" as="element()">
						<table>
							<xsl:copy-of select="@*" />
							<xsl:copy-of select="*" />
						</table>
					</xsl:with-param>
				</xsl:call-template>
			</table1>
		</xsl:variable>

		<xsl:variable name="table2" as="element()">
			<table2>
				<xsl:call-template name="secondTasformation">
					<xsl:with-param name="table1" as="element()">
						<xsl:copy-of select="$table1" />
					</xsl:with-param>
				</xsl:call-template>
			</table2>
		</xsl:variable>

    <!-- 3rd step is to re-invert the table so that it contains only 1*1 cells,
       with the information of where the rowspans and colspans were.
    -->
		<xsl:variable name="tableascells" as="element()">
			<xsl:for-each select="$table2">
				<table>
					<xsl:copy-of select="table/@*" />
					<xsl:copy-of select="table/*[not(name() = 'row')]" />
					<xsl:for-each select="$table2/table/table/row">
						<row>
							<xsl:variable name="positionRow" select="position()" />
							<xsl:for-each select="cell|hcell">
								<xsl:variable name="this" select="." as="element()" />
								<xsl:variable name="thisname" select="$this/name()" />
								<xsl:variable name="positionCell" select="position()" />
								<cell>
									<xsl:choose>
										<xsl:when test="@rowspan">
											<xsl:variable name="currentRowspan" select="@rowspan" />
											<xsl:variable name="previousCell"
												select="$table2/table/table/row[$positionRow - 1]/cell[$positionCell]/@rowspan" />
											<xsl:choose>
												<xsl:when test="number($previousCell) gt number($currentRowspan)">
													<xsl:copy-of select="@*[not(name() = 'rowspan')]" />
													<xsl:attribute name="rowspan">continue</xsl:attribute>
													<xsl:copy-of select="*" />
												</xsl:when>
												<xsl:otherwise>
													<xsl:copy-of select="@*[not(name() = 'rowspan')]" />
													<xsl:attribute name="rowspan">restart</xsl:attribute>
													<xsl:copy-of select="*" />
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:otherwise>
											<xsl:copy-of select="@*" />
											<xsl:copy-of select="*" />
										</xsl:otherwise>
									</xsl:choose>
								</cell>
							</xsl:for-each>
						</row>
					</xsl:for-each>
				</table>
			</xsl:for-each>
		</xsl:variable>

		<xsl:apply-templates select="$tableascells" mode="final" />
	</xsl:template>

	<xsl:template match="text()" mode="final" />

	<xsl:template match="table" mode="final">
		<xsl:if test="caption">
			<w:p>
				<xsl:call-template name="apply-style" />
				<xsl:apply-templates select="caption"  mode="content"/>
			</w:p>
		</xsl:if>
		<w:tbl>
			<w:tblPr>
			 <xsl:choose>
			   <xsl:when test="@role = $configDoc/config/tables/style/@role">
			     		<w:tblStyle w:val="{$configDoc/config/tables/style[@role = current()/@role]/@name}"/>
			   </xsl:when>
			   <xsl:when test="$configDoc/config/tables[@default != '']">
              <w:tblStyle w:val="{$configDoc/config/tables/@default}"/>  
         </xsl:when>
			   <xsl:otherwise>
			     <w:tblBorders>
	          <w:top w:val="single" w:sz="4" w:space="0" w:color="auto" />
	          <w:left w:val="single" w:sz="4" w:space="0" w:color="auto" />
	          <w:bottom w:val="single" w:sz="4" w:space="0" w:color="auto" />
	          <w:right w:val="single" w:sz="4" w:space="0" w:color="auto" />
	          <w:insideH w:val="single" w:sz="4" w:space="0" w:color="auto" />
	          <w:insideV w:val="single" w:sz="4" w:space="0" w:color="auto" />
          </w:tblBorders>
			   </xsl:otherwise>
			 </xsl:choose>
				
			</w:tblPr>
			<xsl:choose>
				<xsl:when test="tgroup/colspec">
					<w:tblGrid>
						<xsl:for-each select="tgroup/colspec">
							<xsl:variable name="colwidth" select="@colwidth" />
							<xsl:variable name="type">in</xsl:variable>
							<xsl:variable name="value"
								select="(substring-before($colwidth,'in'))" />
							<w:gridCol w:w="{format-number(number($value)*1440,'#0') }" />
						</xsl:for-each>
					</w:tblGrid>
				</xsl:when>

				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="row[1][hcell]">
							<xsl:variable name="numCols" select=" count(row[1]/hcell)" />
							<w:tblGrid>
		                       <!--  estimate -->
								<xsl:for-each select="1 to $numCols">
									<w:gridCol w:w="{format-number(if(($TableWidthDxa div $numCols)*$numCols &lt; $TableWidthDxa ) then $TableWidthDxa div $numCols + 1 else $TableWidthDxa div $numCols,'#0') }" />
								</xsl:for-each>
							</w:tblGrid>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="numCols" select=" count(row[1]/cell)" />
							<w:tblGrid>
		                       <!--  estimate -->
								<xsl:for-each select="1 to $numCols">
									<w:gridCol w:w="{format-number(if(($TableWidthDxa div $numCols)*$numCols &lt; $TableWidthDxa ) then $TableWidthDxa div $numCols + 1 else $TableWidthDxa div $numCols,'#0') }" />
								</xsl:for-each>
							</w:tblGrid>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>


			</xsl:choose>
			<xsl:apply-templates select="row"  mode="content"/>

		</w:tbl>
	</xsl:template>

  <!--##row##-->
	<xsl:template match="row" mode="content">
		<w:tr>
			<w:trPr>
				<xsl:if test="hcell">
					<w:tblHeader />
				</xsl:if>
                <!--default: repeat table header, can't split row across pages -->
			</w:trPr>
			<xsl:apply-templates select="hcell | cell"  mode="content"/>
		</w:tr>
	</xsl:template>
  
  <!--##hcell##-->
  <!--##cell##-->
	<xsl:template match="hcell | cell" mode="content">

		<xsl:variable name="realPosition">
			<xsl:choose>
				<xsl:when test="preceding-sibling::*/@colspan">
					<xsl:variable name="tempPosition" select="position()" />
					<xsl:variable name="sumPrevious"
						select="sum((preceding-sibling::*/@colspan)) + count((preceding-sibling::*[not(@colspan)]))" />
					<xsl:value-of select="number($sumPrevious) + 1" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="position()" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="@colspans">
				<xsl:variable name="currentColspan" select="@colspans" />
				<xsl:variable name="valueOfColspan" select="@colspan" />
				<xsl:choose>
					<xsl:when
						test="(following-sibling::*[@colspans = $currentColspan]) and not(preceding-sibling::*[@colspans = $currentColspan])">
						<w:tc>
							<w:tcPr>
								<w:gridSpan
									w:val="{count(following-sibling::*[@colspans = $currentColspan]) + 1}" />
								<xsl:choose>
									<xsl:when test="../hcell">
										<xsl:variable name="numCols">
											<xsl:choose>
												<xsl:when test="count(../../row[1]/hcell) gt 0">
													<xsl:value-of select="count(../../row[1]/hcell)" />
												</xsl:when>
												<xsl:otherwise>
													1
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>

										<w:tcW
											w:w="{format-number(($TableWidthDxa div $numCols)*$valueOfColspan,'#0') }"
											w:type="dxa" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:variable name="numCols">
											<xsl:choose>
												<xsl:when test="count(../../row[1]/cell) gt 0">
													<xsl:value-of select="count(../../row[1]/cell)" />
												</xsl:when>
												<xsl:otherwise>
													1
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<w:tcW
											w:w="{format-number(($TableWidthDxa div $numCols)*$valueOfColspan,'#0') }"
											w:type="dxa" />
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="@rowspan">
									<xsl:choose>
										<xsl:when test="@rowspan = 'restart'">
											<w:vMerge w:val="restart" />
										</xsl:when>
										<xsl:otherwise>
											<w:vMerge w:val="continue" />
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
								<xsl:if test="$realPosition">
									<xsl:variable name="widthCol"
										select="format-number(number(substring-before(../../tgroup/colspec[number($realPosition)]/@colwidth,'in'))*1440,'#0')" />
									<xsl:if test="$widthCol !='NaN'">
										<w:tcW w:w="{$widthCol}" w:type="dxa" />
									</xsl:if>
								</xsl:if>
								<xsl:if test="@width">
									<xsl:choose>
					                <!-- when contains mixed content -->
										<xsl:when test="contains(@width, '%')">
											<xsl:variable name="widthCol">
												<xsl:value-of
													select="format-number(number(substring-before(@width,'%'))*50,'#0')" />
											</xsl:variable>
											<w:tcW w:w="{$widthCol}" w:type="pct" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:variable name="widthCol">
												<xsl:value-of select="format-number(number(@width)*20,'#0')" />
											</xsl:variable>
											<w:tcW w:w="{$widthCol}" w:type="dxa" />
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</w:tcPr>
							<xsl:choose>
			                <!-- when contains mixed content -->
								<xsl:when test="para or paraLabel or mlist or nlist or list">
									<xsl:apply-templates  mode="content"/>
								</xsl:when>
			                <!-- If no content, generate a dummy paragraph anyway -->
								<xsl:when test="not(child::node())">
									<w:p />
								</xsl:when>

								<xsl:otherwise> 									
										<xsl:apply-templates  mode="content"/>
								</xsl:otherwise>
							</xsl:choose>
						</w:tc>

					</xsl:when>
					<xsl:otherwise>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<w:tc>
					<w:tcPr>
						<xsl:choose>
							<xsl:when test="../hcell">
								<xsl:variable name="numCols">
									<xsl:choose>
										<xsl:when test="count(../../row[1]/hcell) gt 0">
											<xsl:value-of select="count(../../row[1]/hcell)" />
										</xsl:when>
										<xsl:otherwise>
											1
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<w:tcW w:w="{format-number(($TableWidthDxa div $numCols),'#0') }"
									w:type="dxa" />
							</xsl:when>

							<xsl:otherwise>
								<xsl:variable name="numCols">
									<xsl:choose>
										<xsl:when test="count(../../row[1]/cell) gt 0">
											<xsl:value-of select="count(../../row[1]/cell)" />
										</xsl:when>
										<xsl:otherwise>
											1
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<w:tcW w:w="{format-number(($TableWidthDxa div $numCols),'#0') }"
									w:type="dxa" />
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="@rowspan">

							<xsl:choose>
								<xsl:when test="@rowspan = 'restart'">
									<w:vMerge w:val="restart" />
								</xsl:when>
								<xsl:otherwise>
									<w:vMerge w:val="continue" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
						<xsl:if test="@rowspans">
							<xsl:variable name="currentRowspan" select="@rowspans" />
							<xsl:choose>
								<xsl:when
									test="(../following-sibling::*//.[@rowspans = $currentRowspan])">
									<xsl:choose>
										<xsl:when
											test="(../preceding-sibling::*//.[@rowspans = $currentRowspan])">
											<w:vMerge w:val="continue" />
										</xsl:when>
										<xsl:otherwise>
											<w:vMerge w:val="restart" />
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<w:vMerge w:val="continue" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
						<xsl:if test="$realPosition">
							<xsl:variable name="widthCol"
								select="format-number(number(substring-before(../../tgroup/colspec[number($realPosition)]/@colwidth,'in'))*1440,'#0')" />
							<xsl:if test="$widthCol !='NaN'">
								<w:tcW w:w="{$widthCol}" w:type="dxa" />
							</xsl:if>

						</xsl:if>
						<xsl:if test="@width">
							<xsl:choose>
				                <!-- when contains mixed content -->
								<xsl:when test="contains(@width, '%')">
									<xsl:variable name="widthCol">
										<xsl:value-of
											select="format-number(number(substring-before(@width,'%'))*50,'#0')" />
									</xsl:variable>
									<w:tcW w:w="{$widthCol}" w:type="pct" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:variable name="widthCol">
										<xsl:value-of select="format-number(number(@width)*20,'#0')" />
									</xsl:variable>
									<w:tcW w:w="{$widthCol}" w:type="dxa" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
					</w:tcPr>
					<xsl:choose>
	                <!-- when contains mixed content -->
						<xsl:when test="para or paraLabel or mlist or nlist or list">
							<xsl:apply-templates  mode="content"/>
						</xsl:when>
	                <!-- If no content, generate a dummy paragraph anyway -->
						<xsl:when test="not(child::node())">
							<w:p />
						</xsl:when>
						<xsl:otherwise>
								<xsl:apply-templates  mode="content"/>
						</xsl:otherwise>
					</xsl:choose>
				</w:tc>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>