<!--
  This is the default template to import a DOCX document as PSML.

  @author Christophe Lauret
  @version 18 February 2013
  
  Current functionalities:
  
  1) Default options:
      a) convert all paragraph styles into:
          i)  para element or
          ii) block element with paragraph style name as a label
      b) convert all character styles into:
          i)  plain text or
          ii) inline element with character style name as a label
              
  2) Document Split according to:
     a) Selected Section Break
     b) Selected Outline Level
     c) Selected Paragraph Style
     
     Naming of each file is defined as '[docx_filename]-[document-split-counter]'
     
  3) Section Split according to:
     a) Selected Section Break
     b) Selected Outline Level
     c) Selected Paragraph Style
     d) ALWAYS break for bookmark ( so that if there is any reference, there will be a section to point to
  
  4) Table of Contents:
      Option to convert or not word TOC ( will be converted as normal sections,paragraphs,xrefs for bookmarks, etc...)
      
  5) Paragraph Styles
      Can be converted into:
        a) Headings
        b) Block elements
        c) Para elements
          i) Para elements can be enumerated with a prefix
        d) Inline elements
        e) Any defined element in the configuration file ( title, etc...) 
        
  6) numbering
     A function for picking up manual numbering is now available [a),b),c);(i),(ii),(iii);1.,2.,3.;etc...] 
     used to number paragraphs and set prefix
      
  7) smartTags are converted and can be:
     a) normal text
     b) inline label     
     
  8) Text runs can be conveted with:
     a) bold
     b) italic
     c) underline
     d) subscript
     e) superscript
     f) with inline label for any text run properties ( Emphasis, Strong, etc...)
        can be:
          i)  A specific inline label
          ii) A pre-defined inline label
  
  9) hyperlinks and bookmarks are converted into xrefs           
  
  10) table styles are saved under the [@role] attribute
  
  11) lists are supported
        TODO: support for named list style as block label
  
  12) images are supported
        
-->
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas"
	xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml"
	xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup"
	xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape"
	xmlns:ct="http://schemas.openxmlformats.org/package/2006/content-types"
	xmlns:fn="http://www.pageseeder.com/function" exclude-result-prefixes="#all">

	<xsl:import href="import/formatting.xsl" />
	<xsl:import href="import/images.xsl" />
	<xsl:import href="import/links.xsl" />
	<xsl:import href="import/paragraphs.xsl" />
	<xsl:import href="import/document-split.xsl" />
	<xsl:import href="import/section-split.xsl" />
	<xsl:import href="import/tables.xsl" />
	<xsl:import href="import/document.xsl" />
	<xsl:import href="import/lists.xsl" />
	<xsl:import href="import/functions.xsl" />
<!-- Root folder -->
  <xsl:strip-space elements="*" />
  <xsl:preserve-space elements="para block"/>
	<xsl:param name="_rootfolder" />

<!-- Output folder -->
	<xsl:param name="_outputfolder" />

	<xsl:param name="_docxfilename"/>
	
	<xsl:param name="_configfileurl"/>

	<xsl:variable name="filename"
		select="substring-before($_docxfilename,'.docx')" />
<!-- [content_types].xml ====================================================================== -->

<xsl:output method="xml" version="1.0" indent="no" encoding="UTF-8" />
<!--
  The root node of "[content_types].xml"
-->

  
	<xsl:variable name="numbering">
		<xsl:value-of
			select="concat($_rootfolder,replace(substring-after(/ct:Types/ct:Override[fn:string-after-last-delimiter(@ContentType,'\.') = 'numbering+xml']/@PartName,'/'),'\\', '/'))" />
	</xsl:variable>

	<xsl:variable name="main">
		<xsl:value-of
			select="concat($_rootfolder,'/word/new-document.xml')" />
	</xsl:variable>

	<xsl:variable name="styles">
		<xsl:value-of
			select="concat($_rootfolder,replace(substring-after(/ct:Types/ct:Override[fn:string-after-last-delimiter(@ContentType,'\.') = 'styles+xml']/@PartName,'/'),'\\', '/'))" />
	</xsl:variable>
  
	<xsl:variable name="configDoc" select="document($_configfileurl)" />

	<xsl:param name="characterStyles">
		<xsl:value-of
			select="$configDoc/config/styles/default/property[@name='characterStyles']/@value" />
	</xsl:param>

	<xsl:param name="paragraphStyles">
		<xsl:value-of
			select="$configDoc/config/styles/default/property[@name='paragraphStyles']/@value" />
	</xsl:param>

	<xsl:variable name="rels"
		select="concat($_rootfolder,'word/_rels/document.xml.rels')" />

	<xsl:template match="/">
		  <xsl:apply-templates select="document($main)"
		  	mode="content"/>
	</xsl:template>

</xsl:stylesheet>
