<?xml version="1.0" encoding="utf-8"?>

  <!--
    This stylesheet transform openXML into PS Format
  
    @author Hugo Inacio 
    @copyright Allette Systems Pty Ltd 
  -->

<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
	xmlns:rs="http://schemas.openxmlformats.org/package/2006/relationships"
	xmlns:cp="http://schemas.openxmlformats.org/package/2006/metadata/core-properties"
	xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:ps="http://www.pageseeder.com/editing/2.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	 exclude-result-prefixes="#all">

  <!-- Values come from configuration file: list of values that specify on what styles to split the document -->
	<xsl:variable name="document-split-styles">
	 <xsl:choose>
     <xsl:when test="$configDoc/config/split/document/type[@name = 'style']/@select = ''">
       <xsl:value-of select="'no Submitted Value'" />
     </xsl:when>
     <xsl:otherwise>
       <xsl:value-of select="$configDoc/config/split/document/type[@name = 'style']/@select" />
     </xsl:otherwise>
   </xsl:choose>
	</xsl:variable>
  
  <!-- Values come from configuration file: list of values that specify on what outline levels to split the document -->
	<xsl:variable name="document-split-outline">
	 <xsl:choose>
     <xsl:when test="$configDoc/config/split/document/type[@name = 'outlineLevel']/@select = ''">
       <xsl:value-of select="'no Submitted Value'" />
     </xsl:when>
     <xsl:otherwise>
       <xsl:value-of select="$configDoc/config/split/document/type[@name = 'outlineLevel']/@select" />
     </xsl:otherwise>
   </xsl:choose>
	</xsl:variable>
  
  <!-- Values come from configuration file: list of values that specify on what section breaks to split the document -->
	<xsl:variable name="document-split-sectionbreak">
	 <xsl:choose>
	   <xsl:when test="$configDoc/config/split/document/type[@name = 'sectionBreak']/@select = ''">
	     <xsl:value-of select="'no Submitted Value'" />
	   </xsl:when>
	   <xsl:otherwise>
	     <xsl:value-of select="$configDoc/config/split/document/type[@name = 'sectionBreak']/@select" />
	   </xsl:otherwise>
	 </xsl:choose>
	</xsl:variable>
  
  <xsl:variable name="maindocument" select="document($main)"/>
  
  <!--  count of total number of files: used to be referenced from xrefs, and also numbering split files -->
  
  <xsl:variable name="number-of-splits">
      <xsl:value-of
        select="count($maindocument//w:p[w:pPr/w:sectPr][w:pPr/w:sectPr/w:type[matches(@w:val,($document-split-sectionbreak))]]) + 
        count($maindocument//w:p[matches(w:pPr/w:pStyle/@w:val, ($document-split-styles))][string-join(w:r//text(), '') != '']) + 
        count($maindocument//w:p[w:pPr/w:pStyle/@w:val = document($styles)/w:styles/w:style[matches(w:pPr/w:outlineLvl/@w:val,($document-split-outline))]/@w:styleId][string-join(w:r//text(), '') != ''])" />

    </xsl:variable>
    
    <!--  variable used to sort output files -->
    <xsl:variable name="zeropadding">
      <xsl:choose>
        <xsl:when test="$number-of-splits &lt; 10">
          <xsl:value-of select="'0'" />
        </xsl:when>
        <xsl:when test="$number-of-splits &lt; 100">
          <xsl:value-of select="'00'" />
        </xsl:when>
        <xsl:when test="$number-of-splits &lt; 1000">
          <xsl:value-of select="'000'" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="'0000'" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
<!-- =============================================================
         Match w:body
         Sections are created for every level of headings
     ============================================================= -->
	<!--##section##-->
	<!--##body##-->

	<xsl:template match="w:body" mode="content">
	  <!-- master document will contain link to all split files  -->
		<section id="content">
			<xref-fragment id="content">
				<!-- Document split for each section break first, then styles then outline level. If any of the breaks match, only only break will be created  -->
				<xsl:for-each-group select="*"
					group-ending-with="w:p[w:pPr/w:sectPr][w:pPr/w:sectPr/w:type[matches(@w:val,($document-split-sectionbreak))]]">
					<xsl:for-each-group select="current-group()"
	group-starting-with="w:p[w:pPr/w:pStyle[@w:val = document($styles)/w:styles/w:style[matches(w:pPr/w:outlineLvl/@w:val,($document-split-outline))]/@w:styleId]][string-join(w:r//text(), '') != '']|w:p[matches(w:pPr/w:pStyle/@w:val, ($document-split-styles))][string-join(w:r//text(), '') != ''] ">

            
							<xsl:variable name="document-number">
			          <xsl:value-of
			        select="count($maindocument//current()/following-sibling::*[1]/preceding::w:p[w:pPr/w:sectPr][w:pPr/w:sectPr/w:type[matches(@w:val,($document-split-sectionbreak))]]) + 
			           count($maindocument//current()/following-sibling::*[1]/preceding::w:p[matches(w:pPr/w:pStyle/@w:val, ($document-split-styles))][string-join(w:r//text(), '') != '']) +  
			           count($maindocument//current()/following-sibling::*[1]/preceding::w:p[w:pPr/w:pStyle/@w:val = document($styles)/w:styles/w:style[matches(w:pPr/w:outlineLvl/@w:val,($document-split-outline))]/@w:styleId][string-join(w:r//text(), '') != '']) 
			           + 1" /> 
			         </xsl:variable>
			        <xsl:variable name="body" as="element()">
                  <body>
                    <xsl:copy-of select="current-group()" />
                  </body>
                </xsl:variable>
                
						<xsl:result-document
							href="{concat($_outputfolder,$filename,'-',format-number(number($document-number), $zeropadding),'.psml')}">
							<document level="portable">
							 <!-- create a body variable to be analysed for each document -->
								<documentinfo>
							    <uri>
							      <displaytitle><xsl:value-of select="$body/w:p[1]//text()"/></displaytitle>
							    </uri>
							  </documentinfo>
								<xsl:apply-templates select="$body" mode="section-split">
								</xsl:apply-templates>
							</document>
						</xsl:result-document>
            <xsl:variable name="current-level">
                <xsl:value-of select="document($styles)/w:styles/w:style[@w:styleId = $body/w:p[1]/w:pPr/w:pStyle/@w:val]/w:pPr/w:outlineLvl/@w:val"/>
              </xsl:variable>
              
            <xsl:variable name="level">
              <xsl:choose>
                <xsl:when test="matches($current-level,($document-split-outline))">
                  <xsl:value-of select="number($current-level) + 1"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>0</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>
						<blockxref title="{$body/w:p[1]//text()}" frag="default" display="manual"
							type="embed" reverselink="true" reversetitle=""
							reversetype="none"
							href="{encode-for-uri(concat($filename,'-',format-number(number($document-number), $zeropadding),'.psml'))}">
<!-- Not currently used: Levels push the heading level down ( so a Heading 1 at level 2, would be a Heading 3) -->
<!-- 							<xsl:if test="$level != '0'"> -->
<!-- 							 <xsl:attribute name="level" select="$level"/> -->
<!-- 							</xsl:if> -->
							<xsl:value-of
								select="concat($filename,'-',format-number(number($document-number), $zeropadding))" />
						</blockxref>
					</xsl:for-each-group>
				</xsl:for-each-group>
			</xref-fragment>
		</section>
	</xsl:template>

</xsl:stylesheet>