<?xml version="1.0" encoding="utf-8"?>

  <!--
    This stylesheet transform openXML into PS Format
  
    @author Hugo Inacio 
    @copyright Allette Systems Pty Ltd 
  -->

<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
	xmlns:rs="http://schemas.openxmlformats.org/package/2006/relationships"
	xmlns:cp="http://schemas.openxmlformats.org/package/2006/metadata/core-properties"
	xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:ps="http://www.pageseeder.com/editing/2.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fn="http://www.pageseeder.com/function" exclude-result-prefixes="#all">

  <!--  List of elements defined to be formatted in the config file -->
	  
  <xsl:variable name="element-property-list">
    <xsl:for-each select="$configDoc/config/styles/element/@name">
      <xsl:choose>
        <xsl:when test="position() = last()">
          <xsl:value-of select="." />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat(.,'|')" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:variable>

  <!--  List of numbering regular expressions to be captured in the config file -->
  <xsl:variable name="numbering-match-list">
    <xsl:for-each select="$configDoc/config/numbering/value">
      <xsl:choose>
        <xsl:when test="position() = last()">
          <xsl:value-of select="@match" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat(@match,'|')" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:variable>
  <!-- apply templates to smart Tags -->
  <xsl:template match="w:smartTag" mode="content">
    <xsl:choose>
      <xsl:when test="$configDoc/config/smart-tag/@keep = 'true'">
        <inline>
          <xsl:attribute name="label"><xsl:value-of select="@w:element" /></xsl:attribute>
          <xsl:apply-templates  mode="content"/>  
        </inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates  mode="content"/>  
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>
  
  <!-- Match each text run individually -->
	<xsl:template match="w:r" mode="content">
		<xsl:param name="fullText" />
		<xsl:param name="inHeading" select="false()" />
		<xsl:variable name="position" select="count(preceding-sibling::w:r)" />
		<xsl:variable name="current" select="current()" />
    
    <!-- Name of text run style (if available) -->
		<xsl:variable name="characterStyleName">
			<xsl:value-of select="./w:rPr/w:rStyle/@w:val" />
		</xsl:variable>

    <!-- Variable to define if an element has been defined for this current style  -->
		<xsl:variable name="inlineValue">
			<xsl:value-of
				select="$configDoc/config/styles/element[@name=$characterStyleName]/property[@name='name']/@value" />
		</xsl:variable>

		<xsl:variable name="bold"
			select="if (current()[w:rPr/w:b]) then 'true' else 'false'" />
		<xsl:variable name="italic"
			select="if (current()[w:rPr/w:i]) then 'true' else 'false'" />
		<xsl:variable name="underline"
			select="if (current()[w:rPr/w:u]) then 'true' else 'false'" />
		<xsl:variable name="sub"
			select="if (current()[w:rPr/w:vertAlign[@w:val='subscript']]) then 'true' else 'false'" />
		<xsl:variable name="sup"
			select="if (current()[w:rPr/w:vertAlign[@w:val='superscript']]) then 'true' else 'false'" />

		<xsl:for-each select="*">
		  <!-- Check if the w:r and containing w:p are numbered -->
			<xsl:variable name="isNumbered">
				<xsl:choose>
					<xsl:when
						test="$position = 0 and matches($fullText,$numbering-match-list) and $configDoc/config/numbering[@select='true']">
						<xsl:value-of select="true()" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>

				<xsl:when test="current()/name() = 'w:t'">
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$characterStyleName" />
						<xsl:with-param name="text" select="current()" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="inlineValue"
							select="if ($inlineValue != '') then $inlineValue else ''" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="current()/name() = 'w:br'">
					<br />
				</xsl:when>
				<xsl:when test="current()/name() = 'w:tab'">
					<xsl:text>&#x9;</xsl:text>
				</xsl:when>
				<xsl:when test="current()/name() = 'w:noBreakHyphen'">
					<xsl:text>-</xsl:text>
				</xsl:when>
				<!--##graphic##-->
				<xsl:when test="current()/name() = 'w:drawing' and not($inHeading)">
<!-- 				  <xsl:message><xsl:value-of select="name()"/></xsl:message> -->
					<xsl:apply-templates select="current()" mode="content" />
				</xsl:when>
				<xsl:when test="current()/name() = 'w:pict' and not($inHeading)">
					<xsl:apply-templates select="current()" mode="content" />
				</xsl:when>
	<!-- 			<xsl:when test="doc-available($footnotes) and w:footnoteReference"> -->
	<!-- 				<sup> -->
	<!-- 					<xref frag="default" display="document" type="None" -->
	<!-- 						reverselink="true" reversetitle="" reversetype="None" -->
	<!-- 						href="footnotes/{w:footnoteReference/@w:id}.xml"> -->
	<!-- 						<xsl:value-of select="w:footnoteReference/@w:id" /> -->
	<!-- 					</xref> -->
	<!-- 				</sup> -->
	<!-- 			</xsl:when> -->
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
<!-- =============================================================
        calls itself recursively to create inline elements
     ============================================================= -->
	<xsl:template name="apply-wr-style">
		<!-- This template processes inline elements recursively -->
		<xsl:param name="style" />
		<xsl:param name="text" />
		<xsl:param name="bold" />
		<xsl:param name="italic" />
		<xsl:param name="underline" />
		<xsl:param name="sub" />
		<xsl:param name="sup" />
		<xsl:param name="inlineValue" />
		<xsl:param name="isNumbered" />
		<xsl:param name="inHeading"/>
		<xsl:choose>
			<xsl:when test="$inlineValue!=''">
        <!--##sup##-->
				<inline>
					<xsl:attribute name="label" select="$inlineValue"></xsl:attribute>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="''" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="''" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</inline>
			</xsl:when>
			<xsl:when test="$style!='' and $characterStyles = 'inlineLabel'">
				<inline label="{$style}">
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="''" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</inline>
			</xsl:when>
			<xsl:when test="$bold='true'">
			   <!--##bold##-->
				<bold>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$style" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="'false'" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</bold>
			</xsl:when>
			<xsl:when test="$italic='true'">
				<!--##italic##-->
				<italic>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$style" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="'false'" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</italic>
			</xsl:when>
			<xsl:when test="$underline='true'">
				<!--##underline##-->
				<underline>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$style" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="'false'" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</underline>
			</xsl:when>
			<xsl:when test="$sub='true'">
				<!--##sub##-->
				<sub>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$style" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="'false'" />
						<xsl:with-param name="sup" select="$sup" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</sub>
			</xsl:when>
			<xsl:when test="$sup='true'">
				<!--##sup##-->
				<sup>
					<xsl:call-template name="apply-wr-style">
						<xsl:with-param name="style" select="$style" />
						<xsl:with-param name="text" select="$text" />
						<xsl:with-param name="bold" select="$bold" />
						<xsl:with-param name="italic" select="$italic" />
						<xsl:with-param name="underline" select="$underline" />
						<xsl:with-param name="sub" select="$sub" />
						<xsl:with-param name="sup" select="'false'" />
						<xsl:with-param name="inlineValue" select="$inlineValue" />
						<xsl:with-param name="inHeading" select="$inHeading" />
						<xsl:with-param name="isNumbered" select="$isNumbered" />
					</xsl:call-template>
				</sup>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$isNumbered = 'true' and $configDoc/config/styles/default/property[@name='prefix'][@value = 'true'] and not($inHeading)">
            <xsl:analyze-string regex="({$numbering-match-list})(.*)"
              select="$text">
              <xsl:matching-substring>
                <xsl:value-of select="regex-group(2)" />
              </xsl:matching-substring>
              <xsl:non-matching-substring>
                <xsl:value-of select="$text" />
              </xsl:non-matching-substring>
            </xsl:analyze-string>
          </xsl:when>
          <xsl:when test="$isNumbered = 'true' and $configDoc/config/numbering[@select = 'true'] and not($inHeading)">
						<xsl:analyze-string regex="({$numbering-match-list})(.*)"
							select="$text">
							<xsl:matching-substring>
								<xsl:variable name="context-string" select="$text" />
								<xsl:for-each select="$configDoc/config/numbering/value">
									<xsl:choose>
										<xsl:when test="matches($context-string,@match)">
											<xsl:element name="{element/@name}">
												<xsl:if test="element/@name = 'inline'">
													<xsl:attribute name="label" select="element/@value" />
												</xsl:if>
												<xsl:value-of select="regex-group(1)" />
											</xsl:element>
										</xsl:when>
									</xsl:choose>
								</xsl:for-each>
								<xsl:value-of select="regex-group(2)" />
							</xsl:matching-substring>
							<xsl:non-matching-substring>
								<xsl:value-of select="$text" />
							</xsl:non-matching-substring>
						</xsl:analyze-string>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$text" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>