<?xml version="1.0" encoding="utf-8"?>

  <!--
    This stylesheet transform openXML into PS Format
  
    @author Hugo Inacio 
    @copyright Allette Systems Pty Ltd 
  -->

<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
	xmlns:rs="http://schemas.openxmlformats.org/package/2006/relationships"
	xmlns:cp="http://schemas.openxmlformats.org/package/2006/metadata/core-properties"
	xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:ps="http://www.pageseeder.com/editing/2.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	exclude-result-prefixes="#all">
  

	<xsl:variable name="numbering-match-list">
		<xsl:for-each select="$configDoc/config/numbering/value">
			<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:value-of select="@match" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="concat(@match,'|')" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:variable>
  
  <xsl:variable name="element-property-list">
    <xsl:for-each select="$configDoc/config/styles/element/@name">
      <xsl:choose>
        <xsl:when test="position() = last()">
          <xsl:value-of select="." />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat(.,'|')" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:variable>
  
	<xsl:template match="w:p" mode="content">
    
    <!-- variable used to check if there is a number or not in the beginning of the paragraph -->
		<xsl:variable name="fulltext">
			<xsl:for-each select=".//w:r/*">
        <xsl:choose>
          <xsl:when test="current()/name() = 'w:br'">
            <xsl:text> </xsl:text>
          </xsl:when>
          <xsl:when test="current()/name() = 'w:tab'">
            <xsl:text> </xsl:text>
          </xsl:when>
          <xsl:when test="current()/name() = 'w:noBreakHyphen'">
            -
          </xsl:when>
          <xsl:when test="current()/name() = 'w:t'">
            <xsl:value-of select="." />
          </xsl:when>
        </xsl:choose>
      </xsl:for-each>
		</xsl:variable>

		
<!-- 		<xsl:apply-templates select="$para" mode="xml"/> -->
		<xsl:variable name="styleName">
			<xsl:value-of select="w:pPr/w:pStyle/@w:val" />
		</xsl:variable>

		<xsl:variable name="new-element">
			<xsl:value-of
				select="$configDoc/config/styles/element[@name=$styleName]/property[@name='style']/@value" />
		</xsl:variable>
    
		<xsl:choose>
      <!-- strip out empty headings -->
			<xsl:when
				test="matches($new-element, 'heading') and string-join((w:r|w:hyperlink)//text(), '') = ''" />	
      <!-- when headings not in tables -->
      <!--##heading##-->
			<xsl:when test="matches($new-element, 'heading') and not(ancestor::w:tbl)">
				<xsl:element name="heading">
					<xsl:attribute name="level"
						select="$configDoc/config/styles/element[@name=$styleName]/property[@name='level']/@value" />
					<xsl:if test="w:pPr/w:numPr/w:numId">
						<xsl:attribute name="numbered">true</xsl:attribute>
					</xsl:if>
					
<!-- 					<xsl:variable name="isNumbered"> -->
<!-- 		        <xsl:choose> -->
<!-- 		          <xsl:when -->
<!-- 		            test="matches(string-join((w:r|w:hyperlink)//text(), ''),$numbering-match-list) and $configDoc/config/numbering[@select='true']"> -->
<!-- 		            <xsl:value-of select="true()" /> -->
<!-- 		          </xsl:when> -->
<!-- 		          <xsl:otherwise> -->
<!-- 		            <xsl:value-of select="false()" /> -->
<!-- 		          </xsl:otherwise> -->
<!-- 		        </xsl:choose> -->
<!-- 		      </xsl:variable> -->
      
<!-- 					<xsl:if test="not(w:pPr/w:numPr/w:numId) and $isNumbered = true()"> -->
<!--             <xsl:attribute name="numbered">true</xsl:attribute> -->
<!--           </xsl:if> -->
					<xsl:apply-templates select="./*" mode="content">
						<xsl:with-param name="inHeading" select="true()" />
						<xsl:with-param name="fullText" select="$fulltext" />
					</xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<!-- when the style is matched to be a block in the config file -->
			<xsl:when test="matches($new-element, 'block')">
				<xsl:element name="{$new-element}">
					<xsl:attribute name="name">
            <xsl:value-of
						select="$configDoc/config/styles/element[@name=$styleName]/property[@name='name']/@value" />
          </xsl:attribute>
					<xsl:apply-templates select="./*"
						mode="content">
						<xsl:with-param name="fullText" select="$fulltext" />
					</xsl:apply-templates>
				</xsl:element>
			</xsl:when>
			<!-- when the style is matched to be a inline in the config file -->
			<xsl:when test="matches($new-element, 'inline')">
				<para>
					<xsl:element name="{$new-element}">
						<xsl:attribute name="label">
	            <xsl:value-of
							select="$configDoc/config/styles/element[@name=$styleName]/property[@name='name']/@value" />
	          </xsl:attribute>
						<xsl:apply-templates select="./*"
							mode="content">
							<xsl:with-param name="fullText" select="$fulltext" />
						</xsl:apply-templates>
					</xsl:element>
				</para>
			</xsl:when>
			<!-- if the element is set to create a para in the config file -->
			<xsl:when test="matches($new-element,'para')">
        <xsl:element name="{$new-element}">
          <xsl:if test="$configDoc/config/styles/element[@name=$styleName]/property[@name='indent']">
            <xsl:attribute name="indent"><xsl:value-of select="$configDoc/config/styles/element[@name=$styleName]/property[@name='indent']/@value" /></xsl:attribute>
          </xsl:if>
          <xsl:if
                test="$configDoc/config/styles/default/property[@name='prefix'][@value = 'true']">
                <xsl:analyze-string regex="({$numbering-match-list})(.*)"
                  select="$fulltext">
                  <xsl:matching-substring>
                    <xsl:attribute name="prefix">
                      <xsl:value-of select="regex-group(1)" />
                    </xsl:attribute>
                  </xsl:matching-substring>
                </xsl:analyze-string>
              </xsl:if>
          <xsl:apply-templates select="./*"
            mode="content">
            <xsl:with-param name="fullText" select="$fulltext" />
          </xsl:apply-templates>
        </xsl:element>
      </xsl:when>
			<!-- when list -->
			<!--##list##-->
			<xsl:when test="w:pPr/w:numPr[w:ilvl][w:numId]">
				<xsl:variable name="listID" select="w:pPr/w:numPr/w:numId/@w:val" />
        <xsl:choose>
          <xsl:when
            test="preceding-sibling::w:p[1][./w:pPr/w:numPr/w:numId/@w:val]" />
          <xsl:otherwise>
						<xsl:call-template name="list">
							<xsl:with-param name="abstractId"
								select="document($numbering)/w:numbering/w:num[@w:numId=$listID]/w:abstractNumId/@w:val" />
							<xsl:with-param name="level" select="w:pPr/w:numPr/w:ilvl/@w:val" />
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>  
				  <!-- if the element is set to create a block in the config file -->
					<xsl:when test="$paragraphStyles = 'block' and $styleName !=''">
						<block label="{$styleName}">
							<xsl:apply-templates select="./*"
								mode="content">
								<xsl:with-param name="fullText" select="$fulltext" />
							</xsl:apply-templates>
						</block>
					</xsl:when>
					<xsl:otherwise>
						<para>
							<xsl:if
								test="$configDoc/config/styles/default/property[@name='prefix'][@value = 'true']">
								<xsl:analyze-string regex="({$numbering-match-list})(.*)"
									select="$fulltext">
									<xsl:matching-substring>
										<xsl:attribute name="prefix">
		                        <xsl:value-of select="regex-group(1)" />
		                        </xsl:attribute>
									</xsl:matching-substring>
								</xsl:analyze-string>
							</xsl:if>
							<xsl:apply-templates select="./*"
								mode="content">
								<xsl:with-param name="fullText" select="$fulltext" />
							</xsl:apply-templates>
						</para>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>