<?xml version="1.0" encoding="utf-8"?>

  <!--
    This stylesheet transform openXML into PS Format
  
    @author Hugo Inacio 
    @copyright Allette Systems Pty Ltd 
  -->

<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ve="http://schemas.openxmlformats.org/markup-compatibility/2006"
	xmlns:o="urn:schemas-microsoft-com:office:office"
	xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
	xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
	xmlns:v="urn:schemas-microsoft-com:vml"
	xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
	xmlns:w10="urn:schemas-microsoft-com:office:word"
	xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
	xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
	xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture"
	xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main"
	xmlns:rs="http://schemas.openxmlformats.org/package/2006/relationships"
	xmlns:cp="http://schemas.openxmlformats.org/package/2006/metadata/core-properties"
	xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:ps="http://www.pageseeder.com/editing/2.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	  xmlns:fn="http://www.pageseeder.com/function" exclude-result-prefixes="#all">



	<!-- =============================================================
             match w:tbl
             table style is turned into @type
         ============================================================= -->
	<xsl:template match="w:tbl" mode="content">
    <!--##table##-->
		<table>
			<xsl:if test="w:tblPr/w:tblStyle/@w:val!=''">
				<!-- if the table has a style name, create the style attribute -->
				<xsl:attribute name="role">
    			<xsl:value-of select="w:tblPr/w:tblStyle/@w:val" />
    		</xsl:attribute>
			</xsl:if>
			<xsl:if test="count(w:tr) = 0">
				<row>
					<cell />
				</row>
			</xsl:if>
			
			
			<xsl:apply-templates select="w:tr" mode="content" />
		</table>
	</xsl:template>


	<xsl:template match="w:tr" mode="content">
    <!--##row##-->
		<row>
			<xsl:choose>
				<xsl:when test="w:trPr/w:tblHeader">
				<!-- when repeat table header is on, this row should contain hcells -->
					<xsl:apply-templates select="w:tc" mode="hcell" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="w:tc" mode="content" />
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="count(w:tc) = 0">
				<cell />
			</xsl:if>
		</row>
	</xsl:template>
  
	<xsl:template match="w:tc" mode="content">
    <!--##cell##-->
    <xsl:choose>
      <xsl:when test="w:tcPr/w:vMerge[not(@w:val)]">
      
      </xsl:when>
      <xsl:otherwise>
        <cell>
          <xsl:if test="w:tcPr/w:gridSpan">
            <xsl:attribute name="colspan" select="w:tcPr/w:gridSpan/@w:val" />
          </xsl:if>
          <xsl:if test="w:tcPr/w:vMerge[@w:val = 'restart']">
              <xsl:variable name="this.colnum"
                select="count(preceding-sibling::w:tc) + 1 +
                sum(preceding-sibling::w:tc/w:tcPr/w:gridSpan/@w:val) -
                count(preceding-sibling::w:tc/w:tcPr/w:gridSpan[@w:val])"/>

              <xsl:attribute name="rowspan">
                <xsl:variable name="remainder">
                <xsl:call-template name="count-rowspan">
                        <xsl:with-param name="row" select="../following-sibling::w:tr[1]"/>
                        <xsl:with-param name="colnum" select="$this.colnum"/>
                    </xsl:call-template>
                 </xsl:variable>
                 <xsl:value-of select="number($remainder) + 1"/>   
              </xsl:attribute>
          </xsl:if>
          <xsl:apply-templates />
        </cell>
      </xsl:otherwise>
    </xsl:choose>
    <!-- else, no content or merged cells -->
  </xsl:template>
  
  <xsl:template name="count-rowspan">
        <xsl:param name="row" select="/.."/>
        <xsl:param name="colnum" select="0"/>
        
        <xsl:variable name="cell"
            select="$row/w:tc[count(preceding-sibling::w:tc) + 1 +
sum(preceding-sibling::w:tc/w:tcPr/w:gridSpan/@w:val) -
count(preceding-sibling::w:tc/w:tcPr/w:gridSpan[@w:val]) = $colnum]"/>
        
        <xsl:choose>
            <xsl:when test="not($cell)">
                <xsl:text>0</xsl:text>
            </xsl:when>
            <xsl:when test="$cell/w:tcPr/w:vMerge[not(@w:val = 'restart')]">
                <xsl:variable name="remainder">
                    <xsl:call-template name="count-rowspan">
                        <xsl:with-param name="row"
                            select="$row/following-sibling::w:tr[1]"/>
                        <xsl:with-param name="colnum" select="$colnum"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:value-of select="$remainder + 1"/>
            </xsl:when>
            <xsl:otherwise>0</xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
	<xsl:template match="w:tc" mode="hcell">
    <!--##hcell##-->
		<hcell>
			<xsl:if test="w:tcPr/w:gridSpan">
				<xsl:attribute name="colspan" select="w:tcPr/w:gridSpan/@w:val" />
			</xsl:if>
			<xsl:apply-templates mode="content" />
		</hcell>
		<!-- else, no content or merged cells -->
	</xsl:template>

</xsl:stylesheet>