<?xml version="1.0"?>
<!--
  A collection of general utility functions used for the blocks.

  @author Christophe Lauret
  @version 2 December 2009

  Copyright (C) 2009 Weborganic Systems Pty. Ltd.
-->
<xsl:stylesheet version="2.0"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:psf="http://www.pageseeder.com/function"
                xmlns:system="java:java.lang.System"
                xmlns:dec="java:java.net.URLDecoder"
                xmlns:enc="java:java.net.URLEncoder"
                exclude-result-prefixes="xs psf dec enc system">

<!-- the id of the component -->
<xsl:param name="component.id" />

<!-- the state of the component -->
<xsl:param name="component.state" />

<!--
  Load and toggle button function

  @param component-id  The ID of the block
  @param dynamic-url   The URL of the block (to retrieve content), if empty string, no loading
  @param ignore-cookie Whether the cookie should be used or not.
-->
<xsl:function name="psf:load-and-toggle-button">
  <xsl:param name="component-id" />
  <xsl:param name="dynamic-url" />
  <xsl:param name="ignore-cookie" />
  <!-- The button is a simple link -->
  <a href="#">
    <xsl:choose>
      <!-- Only when the block ID is specified -->
      <xsl:when test="$component-id != ''">
        <xsl:attribute name="title">Expand / Collapse</xsl:attribute>
        <xsl:attribute name="class">button</xsl:attribute>
        <xsl:attribute name="id">button-<xsl:value-of select="$component-id"/></xsl:attribute>
        <xsl:if test="$dynamic-url != ''"><xsl:attribute name="url" select="$dynamic-url" /></xsl:if>
        <xsl:if test="not($ignore-cookie = true())"><xsl:attribute name="cookie">ps-blocks-cookie</xsl:attribute></xsl:if>
      </xsl:when>
      <!-- Cannot be collapsed -->
      <xsl:otherwise>
        <xsl:attribute name="title">This item cannot be collapsed</xsl:attribute>
        <xsl:attribute name="class">button collapse</xsl:attribute>
        <xsl:attribute name="onclick">JavaScript:return false;</xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>&#160;</xsl:text>
  </a>
</xsl:function>

<!--
  Function to generate toggle comment button
-->
<xsl:function name="psf:display-attribute">
  <!-- Whether the branch should be expand/collapse. -->
  <xsl:param name="state" as="xs:string"/>
  <xsl:if test="$state = 'expand'">
    <xsl:attribute name="style">display: none</xsl:attribute>
  </xsl:if>
</xsl:function>
<!--
  Given a page parameter string, replace one of the paramenter value in the string.
-->
<xsl:function name="psf:replace-param">
  <!-- The parameter string -->
  <xsl:param name="parameters"/>
  <!-- The name of the paramenter to be replaced -->
  <xsl:param name="param-name"/>
  <!-- The value for the parameter -->
  <xsl:param name="value"/>
  <xsl:value-of select="string-join(psf:replace-param-helper($parameters,$param-name,$value),'&amp;')"/>
</xsl:function>

<!--
  Given a page parameter string, replace one of the paramenter value in the string.
  Helper function for psf:replace-param
-->
<xsl:function name="psf:replace-param-helper">
  <!-- The parameter string -->
  <xsl:param name="parameters"/>
  <!-- The name of the paramenter to be replaced -->
  <xsl:param name="param-name"/>
  <!-- The value for the paramete -->
  <xsl:param name="value"/>
  <xsl:for-each select="tokenize($parameters,'&amp;')">
    <xsl:choose>
    <xsl:when test="starts-with(.,$param-name)">
      <xsl:value-of select="concat($param-name,'=',$value)"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="."/>
    </xsl:otherwise>
  </xsl:choose>
  </xsl:for-each>
  <!--if there's nothing to replace, then append the param name and value -->
  <xsl:if test="not(contains($parameters, $param-name))">
    <xsl:value-of select="concat($param-name,'=',$value)"/>
  </xsl:if>
</xsl:function>

</xsl:stylesheet>