<?xml version="1.0"?>
<!-- 
  This schematron defines the general best practice recommendations by Weborganic for basic 
  PageSeeder Standard Format documents (which do not use complex templates)

  The schematron rules defined here are meant to provide guidance for users on how to 
  produce quality PS Standard documents. Whenever possible, the rule should explain why
  the recommendation is made.  

  For a PageSeeder standard document, the source document will follow the following structure:

  <?stylesheet format="standard" config="[document-type?]" css="[css?]" docid="[docid?]" title="[title]"?>
  <root>
    <ps:documentinfo xmlns:ps="http://www.pageseeder.com/editing/2.0" edit="[true|false]">
      <ps:uri id="10663" docid="[docid?]" scheme="[http|https]" host="[host]" port="[port]" behavior="[behaviour]" path="[path]" decodedpath="[decoded-path]">
        <ps:displaytitle>[display-title]</ps:displaytitle>
      </ps:uri>
      <ps:releases release="Current"/>
      <ps:reversexrefs>
        <ps:reversexref uriid="[uriid]" frag="[fragmentid]" title="" href="[href]" urititle="[urititle]" id="[xlinkid]" type="[xreftype]" forwardtitle="[title]" forwardtype="[xreftype]"/>
        <ps:reversexref ... />
        ...
      </ps:reversexrefs>
    </ps:documentinfo>
    <ps:fragmentinfo xmlns:ps="http://www.pageseeder.com/editing/2.0">
      <ps:fragment id="[fragment-id]" modifieddate="[datetime]" locatorid="[locatorid]" xlinkid="[xlinkid]"/>
      <ps:fragment ... />
      ...
    </ps:fragmentinfo>
    <properties>
      <property name="document-type">[document-type]</property>
    </properties>
    <section id="[section-id]"> ... </section>
    <section id="[section-id]"> ... </section>
    ...
  </root>

  @author Christophe Lauret
  @version 14 February 2012
-->
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron"
            xmlns:ps="http://www.pageseeder.com/editing/2.0" title="Titles">

  <sch:ns prefix="ps" uri="http://www.pageseeder.com/editing/2.0"/>

  <!--
    Set of rules applying to the entire document
  -->
  <sch:pattern name="Document">

    <!-- No Abstract/description -->

    <sch:rule context="/root">

      <!-- URI title does not match the first heading -->
      <sch:assert test="ps:documentinfo/ps:uri/ps:displaytitle = (section[1]/body/heading1)[1]">The title of this document '<sch:value-of select="ps:documentinfo/ps:uri/ps:displaytitle"/>' does not match 
      the first heading of the content '<sch:value-of select="(section[1]/body/heading1)[1]"/>'.</sch:assert>

      <!-- Too many sections -->
      <sch:assert test="count(section) le 20">Your document contains over 20 sections.
      Having too many sections in a document make it difficult to read and edit and may lead to performance issues.
      You should consider splitting your document into multiple documents.</sch:assert>

      <!-- No Doc ID -->
      <sch:report test="not(ps:documentinfo/ps:uri/@docid)">Your document does not have a Doc ID.
      Specifying a Doc ID makes it easier to identify and find your document in PageSeeder.</sch:report>

      <!-- No Label -->
      <sch:report test="not(ps:documentinfo/ps:uri/ps:labels)">Your document has no label.
      Attaching labels to a document makes it easier to categorise and find your document in PageSeeder.</sch:report>

      <!-- Number of words-->
      <sch:report test="section">Document contains '<sch:value-of select="count(tokenize(string-join(section//text(), ' '), ' '))"/>' words.</sch:report>

    </sch:rule>

  </sch:pattern>

  <!--
    Set of rules applying to the document sections
  -->
  <sch:pattern name="Sections">

    <sch:rule context="section/body">

      <!-- Section has no heading -->
      <sch:assert test="starts-with(name(*[1]), 'heading')">Section body '<sch:value-of select="@id"/>' has no title.
      It is better practice to start each section with a heading.</sch:assert>

      <!-- Section has multiple headings -->
      <sch:assert test="count(heading1|heading2|heading3|heading4|heading5) le 1">Section body '<sch:value-of select="@id"/>' has multiple headings!</sch:assert>

      <!-- Too long (over 2000 chars)-->
      <sch:assert test="string-length(string-join(.//text(), '')) le 2000">Section body '<sch:value-of select="@id"/>' has over 2000 characters.
      You should consider splitting this section.</sch:assert>

      <!-- Section has multiple headings -->
      <sch:assert test="not(.//table/@align)">Section body '<sch:value-of select="@id"/>' has a table with align set (align is not supported here).</sch:assert>

    </sch:rule>

  </sch:pattern>

</sch:schema>
