<?xml version="1.0"?> 
<!--
  This stylesheet provides the consolidated_document.xml
  Doing the XLink /xrefs processing, also include, replace.

  @author  William Liem
  @version 28 September 2007
-->
<xsl:stylesheet version="2.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xs="http://www.w3.org/2001/XMLSchema"
				xmlns:ps="http://www.pageseeder.com/editing/2.0"
				xmlns:xhtml="http://www.w3.org/1999/xhtml"
				xmlns:dec="java:java.net.URLDecoder">

  <xsl:output method="xml" encoding="UTF-8" indent="no"/>
  	
  <xsl:param name="in-folder" select="'.'"/>
  <xsl:param name="ps-sitePrefix"/>
  <xsl:param name="ps-uriId"/>
  <xsl:param name="ps-uriPath"/>
  <xsl:param name="ps-uriFolder"/>
  <xsl:param name="level" select="5"/>
  <xsl:param name="xsl-toc" select="'false'"/>
  
  <xsl:template match="/">
  	<xsl:apply-templates>
  		<!-- @param count does the incrementation of cycle level -->
  		<xsl:with-param name="count" select="0" tunnel="yes"/>
  		<xsl:with-param name="base-uri" select="$ps-uriFolder" tunnel="yes"/>
  	</xsl:apply-templates>
  </xsl:template>
  
  <xsl:template match="processing-instruction()">
    <xsl:copy-of select="."/>
  </xsl:template>
  
  <!-- process not only /root, but also root as sub-element of section for Include -->
  <!-- @param uriid: uriid of current section, empty string otherwise -->
  <!-- @param parents: parents uriid of current section, empty string otherwise -->
  <xsl:template match="root">
  	<xsl:param name="count"           select="0" tunnel="yes"/>
  	<xsl:param name="uriid"           select="''"/>
  	<xsl:param name="parents"         select="''"/>
    <xsl:param name="config"          select="''"/>
    <xsl:param name="numbering-level" select="0" tunnel="yes" />
  	
  	<root uriid="{if ($uriid='') then $ps-uriId else $uriid}">
      <xsl:copy-of select="@level"/>
      <xsl:if test="$config != ''"><xsl:attribute name="config" select="$config" /></xsl:if>
      <xsl:if test="$uriid=''">
  		  <ps:documentinfo>
  		    <ps:uri id="{$ps-uriId}"/>
  		  </ps:documentinfo>
  	  </xsl:if>
  		<xsl:copy-of select="title"/>
  		<xsl:apply-templates select="section">
  			<xsl:with-param name="uriid" select="$uriid"/>
  			<xsl:with-param name="count" select="$count" tunnel="yes"/>
  			<xsl:with-param name="parents" select="$parents" tunnel="yes"/>
        <xsl:with-param name="numbering-level" select="if (@level) then $numbering-level + number(@level) else $numbering-level" tunnel="yes" />
  		</xsl:apply-templates>
  	</root>
  </xsl:template>
  
  <xsl:template match="ps:documentInfo | ps:documentinfo | ps:fragmentinfo"/>	
  
  <!-- always copy toc for top document and only copy it for sub-docs if xsl-toc = 'true' -->
  <xsl:template match="section[toc]">
  	<xsl:param name="uriid" select="''"/>
  	<xsl:if test="$uriid='' or $xsl-toc = 'true'">
      <xsl:copy>
        <xsl:copy-of select="@*[name() != 'id']"/>
        <xsl:attribute name="id" select="if ($uriid = '') then 'toc' else concat($uriid, '-toc')"/>
        <xsl:copy-of select="*"/>
      </xsl:copy>
    </xsl:if>
  </xsl:template>
  
  <xsl:template match="section[not(toc)]">
  	<xsl:param name="uriid" select="''"/>
  	<xsl:param name="count" tunnel="yes"/>
  	<xsl:param name="parents"/>
  
  	<!-- 2. Copy section value -->
  	<xsl:copy>
  		<xsl:copy-of select="@*"/>
  		<!-- insert section id -->
  		<xsl:variable name="id-prefix" select="if ($uriid = '') then '' else concat($uriid,'-')"/>
  		<xsl:attribute name="id" select="concat($id-prefix,@id)"/>
  		<xsl:copy-of select="*[not(self::body)]"/>
  		<xsl:apply-templates select="body">
  			<xsl:with-param name="uriid"     select="$uriid"/>
  			<xsl:with-param name="parents"   select="$parents"/>
  			<xsl:with-param name="count"     select="$count" tunnel="yes"/>
  		</xsl:apply-templates>
  	</xsl:copy>
  	
  </xsl:template>
  	
  <xsl:template match="body">
  	<xsl:param name="uriid"/>
  	<xsl:param name="parents"/>
  	<xsl:param name="count" tunnel="yes"/>
  	<xsl:param name="base-uri" tunnel="yes"/>
    <xsl:param name="numbering-level" select="0" tunnel="yes"/>
  	  
  	<!-- 1. get the Include XRef -->
  	<xsl:variable name="list-xref">
  		<xsl:for-each select=".//(xref | blockXref)[@href and contains(@href,'.xml') and (@type='Include' or @type='Replace')]">
  			<xsl:copy>
  				<xsl:copy-of select="@*"/>
  				<xsl:attribute name="position" select="position()"/>
  				<xsl:attribute name="parents" select="if ($parents='') then $ps-uriPath else $parents"/>
  			</xsl:copy>
  		</xsl:for-each>
  	</xsl:variable>
  	<xsl:copy>
  		<xsl:copy-of select="@*"/>     
      <xsl:variable name="id-prefix" select="if ($uriid = '') then '' else concat($uriid,'-')"/>
  		<!-- if body doesn't have id, inherit from parent section -->
  		<xsl:attribute name="id" select="if (@id) then concat($id-prefix,@id) else concat($id-prefix,../@id)"/>
  		<!-- where do we get explanation about the current uriid -->
  		<xsl:choose>
  			<xsl:when test=".//(xref | blockXref)[@type='Replace'] and number($count) &lt; number($level)"/>
  			<xsl:otherwise>
  				<xsl:apply-templates select="node()" mode="copy">
            <xsl:with-param name="numbering-level" select="if (@level) then $numbering-level + number(@level) else $numbering-level" tunnel="yes" />
          </xsl:apply-templates>
  			</xsl:otherwise>
  		</xsl:choose>
  	</xsl:copy>
  	
  	<!-- 3. Process the XRef Links -->
  	<xsl:if test="count($list-xref/*) > 0 and number($count) &lt; number($level)">
  		<xsl:for-each select="$list-xref/*">
  			<xsl:variable name="uri-paths" select="tokenize(@href,'/')"/>
  			<xsl:variable name="uri-filename" select="$uri-paths[position()=last()]"/>
  			<xsl:variable name="uri-folder-path" select="substring-before(@href,concat('/',$uri-filename))"/><!--
        <xsl:variable name="level" select="if (@level) then $numbering-level + number(@level) else $numbering-level" />
  			--><xsl:variable name="temp">
  				<xsl:choose>
  					<!-- if fragment exists then we open the file using document(),
  						 and use xPath to get to the section according to the fragment
  					  -->
  					<xsl:when test="@frag!='default'">
  						<xsl:variable name="link" select="dec:decode(@href,'UTF-8')"/>
  						<xsl:variable name="frag" select="@frag"/>
  						<!-- adding root element so that it can match for fragment='default' -->
  						<root>
                <xsl:if test="@level"><xsl:attribute name="level" select="@level" /></xsl:if>
  							<section>
  								<xsl:copy-of select="document(concat('file:///',$in-folder,$link))//section[body[@id=$frag]]/@*"/>
  								<xsl:copy-of select="document(concat('file:///',$in-folder,$link))//body[@id=$frag]" />
  							</section>
  						</root>
  					</xsl:when>
  					<!-- no fragment -->
  					<xsl:otherwise>
              <xsl:variable name="root" select="document(concat('file:///',$in-folder,dec:decode(@href,'UTF-8')))/root" />
              <root>
                <xsl:if test="@level"><xsl:attribute name="level" select="@level" /></xsl:if>
                <xsl:copy-of select="$root/@* | $root/*"/>
              </root>
  					</xsl:otherwise>
  				</xsl:choose>
  			</xsl:variable>
  			
  			<!-- 28 September 2007 adding group permission checking -->
  			<xsl:choose>
  				<xsl:when test="$temp/root/status='access-denied'">
  					<!-- if Access Denied, print back the xref -->
  					<body id="{generate-id()}">
  						<xsl:copy-of select="."/>
  					</body>
  				</xsl:when>
  				<xsl:otherwise>
  					<xsl:apply-templates select="$temp/root">
  						<xsl:with-param name="count"    select="$count + 1" tunnel="yes"/>
  						<xsl:with-param name="uriid"    select="@uriid"/>
  						<xsl:with-param name="parents"  select="if ($uriid='') then @parents else concat(@parents,',',$uriid)"/>
  						<xsl:with-param name="base-uri" select="$uri-folder-path" tunnel="yes"/>
  	          <xsl:with-param name="config"   select="@uriconfig"/>
              <xsl:with-param name="numbering-level" select="$numbering-level" tunnel="yes"/>
  					</xsl:apply-templates>
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:for-each>
  	</xsl:if>
  </xsl:template>
  
  <xsl:template match="*" priority="-1"/>
  
  <xsl:template match="text()" mode="copy">
  	<xsl:value-of select="." />
  </xsl:template>
  
  <xsl:template match="*" mode="copy">
  	<xsl:copy>
  		<xsl:copy-of select="@*" />
  		<xsl:apply-templates select="node()" mode="copy" />
  	</xsl:copy>
  </xsl:template>
  
  <xsl:template match="graphic" mode="copy">
  	<xsl:param name="base-uri" tunnel="yes" />
  	<xsl:copy>
  		<xsl:copy-of select="@*[not(local-name()='src')]" />
  		<xsl:attribute name="src" select="if (starts-with(@src, '/')) then @src else concat($base-uri,'/',@src)"/>
  		<xsl:apply-templates select="node()" mode="copy" />
  	</xsl:copy>
  </xsl:template>
  
  <xsl:template match="blockXref[@type = 'Embed' or @type = 'Transclude']" mode="copy">
    <xsl:param name="count"           tunnel="yes" select="0"/>
    <xsl:param name="parents"         tunnel="yes" select="''" />
    <xsl:param name="numbering-level" tunnel="yes" select="0" />
    <xsl:copy>
      <xsl:copy-of select="@*" />
      <xsl:choose>
      <xsl:when test="number($count) &lt; number($level)">
        <xsl:variable name="target">
          <xsl:choose>
            <!-- internal target, whole document -->
            <xsl:when test="starts-with(@href, '#') and @frag = 'default'">
              <root level="{if (@level) then @level else 0}">
                <xsl:copy-of select="/root/@*" />
                <xsl:sequence select="/root/*" />
              </root>
            </xsl:when>
            <!-- internal target, single fragment -->
            <xsl:when test="starts-with(@href, '#')">
              <xsl:variable name="body" select="//section/body[@id=current()/@frag]" />
              <body level="{if (@level) then @level else 0}">
                <xsl:copy-of select="$body/../@*" />
                <xsl:sequence select="$body/node()" />
              </body>
            </xsl:when>
            <!-- external XML target, whole document -->
            <xsl:when test="ends-with(@href, '.xml') and @frag = 'default'">
              <xsl:choose>
                <xsl:when test="doc-available(concat('file:///', $in-folder, @href))">
                  <xsl:variable name="doc-root" select="document(concat('file:///', $in-folder, @href))/root" />
                  <root level="{if (@level) then @level else 0}">
                    <xsl:copy-of select="$doc-root/@*" />
                    <xsl:sequence select="$doc-root/*" />
                  </root>
                </xsl:when>
                <xsl:otherwise>
                  <root><message>Invalid document <xsl:value-of select="@href" /></message></root>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
            <!-- external XML target, a fragment -->
            <xsl:when test="contains(@href, '.xml') and @frag != 'default'">
              <xsl:choose>
                <xsl:when test="doc-available(concat('file:///', $in-folder, @href))">
                  <xsl:variable name="body" select="document(concat('file:///', $in-folder, @href))//section/body[@id=current()/@frag]" />
                  <body level="{if (@level) then @level else 0}">
                    <xsl:copy-of select="$body/../@*" />
                    <xsl:sequence select="$body/node()" />
                  </body>
                </xsl:when>
                <xsl:otherwise>
                  <root><message>Invalid document <xsl:value-of select="@href" /></message></root>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
            <!-- external non-XML target -->
            <xsl:otherwise><xsl:sequence select="text()" /></xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:choose>
          <xsl:when test="$target/root/message">
            <xsl:attribute name="message" select="$target/root/message" />
            <xsl:apply-templates mode="copy" />
          </xsl:when>
          <xsl:when test="$target/root/status='access-denied'">
            <xsl:attribute name="message">Access Denied</xsl:attribute>
            <xsl:apply-templates mode="copy" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="$target/*">
              <xsl:with-param name="count" select="$count + 1"/>
              <xsl:with-param name="uriid" select="@uriid"/>
              <xsl:with-param name="parents" select="concat($parents,',',@uriid)"/>
              <xsl:with-param name="base-uri" select="string-join(tokenize(@href, '/')[position() != last()], '/')" tunnel="yes"/>
              <xsl:with-param name="numbering-level" select="$numbering-level" tunnel="yes"/>
            </xsl:apply-templates>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise><xsl:value-of select="."/></xsl:otherwise>
      </xsl:choose>
    </xsl:copy>
  </xsl:template>
  
  <!-- precede body ID with the parent uri id -->
  <xsl:template match="body" mode="copy">
    <xsl:param name="uriid" select="''" tunnel="yes"/>
    <xsl:copy>
      <xsl:copy-of select="@*" />
      <xsl:attribute name="id" select="if (@id) then concat($uriid, '-',@id) else concat($uriid, '-',../@id)"/>
      <xsl:apply-templates mode="copy" />
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="blockXref[not(@type = 'Embed' or @type = 'Transclude')]" mode="copy">
    <xsl:param name="count" select="0" />
    <!-- Strip it -->
  </xsl:template>
  
  <xsl:template match="xref[starts-with(@href, '#')]" mode="copy">
    <xsl:param name="uriid" select="''" tunnel="yes"/>
    <xsl:choose>
      <xsl:when test="$uriid=''">
        <xsl:copy-of select="." />
      </xsl:when>
      <xsl:otherwise>
        <xref href="#psFrag{@uriid}-{@frag}">
          <xsl:copy-of select="@*[not(local-name()='href')]" />
          <xsl:apply-templates mode="copy"/>
        </xref>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!-- handle headings level -->
  <xsl:template match="heading1 | heading2 | heading3 | heading4 | heading5 | heading6" mode="copy">
    <xsl:param name="numbering-level" tunnel="yes" select="0" />

    <xsl:variable name="this-level" select="number(substring-after(name(), 'heading')) + $numbering-level" />
    <!-- for heading > 6, use the element name 'heading' with a level attribute -->
    <xsl:element name="heading{if ($this-level gt 6) then '' else $this-level}">
      <xsl:copy-of select="@*" />
      <xsl:if test="$this-level gt 6"><xsl:attribute name="level" select="$this-level" /></xsl:if>
      <xsl:apply-templates mode="copy" />
    </xsl:element>
  </xsl:template>

</xsl:stylesheet>