<?xml version="1.0"?>
<!-- 
  This stylesheet transforms openXML into HTML format
 -->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:ps="http://www.pageseeder.com/editing/2.0" xmlns="http://www.w3.org/1999/xhtml" xmlns:psf="http://www.pageseeder.com/function">

  <xsl:import href="../../../default/format-standard/Common/RichTextToHTML.xsl" />
  <xsl:import href="../../../default/Layout/Common/page-functions.xsl" />

  <xsl:output method="html" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01//EN" />

  <xsl:param name="siteprefix" select="''" />
  <xsl:param name="stylegroupname" select="''" />
  <xsl:param name="urihost" />
  <xsl:param name="uriport" />
  <xsl:param name="uriid" select="''" />

	<xsl:param name="styleowner" select="''"/>
	<xsl:param name="stylecss" select="''"/>
	<xsl:param name="xsl-toc" select="''"/>

	<xsl:variable name="css-path">
	    <xsl:choose>
	    <xsl:when test="$styleowner!='' and $stylecss!=''">
	      <xsl:value-of select="concat('http://',$urihost,':',$uriport,$siteprefix,'/woconfig/',$styleowner,'/css/',$stylecss,'.css')"/>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="concat('http://',$urihost,':',$uriport,$siteprefix,'/weborganic/document/css/standard.css')"/>
	    </xsl:otherwise>
	    </xsl:choose>  
	 </xsl:variable>

  <!-- @param firstpass: containing the path to all Include xrefs in xrefs.xml 
  <xsl:param name="firstpass" />

  <xsl:variable name="include-xrefs" select="document($firstpass)" />-->
  <xsl:variable name="xsl-action" select="'preview'" />

  <xsl:template match="/" name="main">
    <html>
      <xsl:variable name="title">
        <xsl:choose>
          <xsl:when test="root/title">
            <xsl:value-of select="root/title" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="(//*[starts-with(local-name(),'heading')])[1]" />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <head>
        <title>
          <xsl:value-of select="$title" />
        </title>
        <link rel="stylesheet" href="{$css-path}" type="text/css" />
      </head>
      <xsl:comment>
       <xsl:text>no seeding</xsl:text>
      </xsl:comment>
      <body>
        <div id="ps-editdocument">
          <xsl:if test="root/title">
            <p class="title0">
              <xsl:value-of select="root/title" />
            </p>
          </xsl:if>

          <xsl:apply-templates select="root/section" />
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="root">
    <xsl:if test="not((preceding::root | ancestor::root)[@uriid=current()/@uriid])">
      <a name="{@uriid}"/>
    </xsl:if>
    <xsl:apply-templates />
  </xsl:template>

<xsl:template match="section[not(toc)]">
  <xsl:choose>
    <!-- Not a section table -->
    <xsl:when test="not(title/@level='table')">
      <!-- Add checking for the title only when body not empty --> 
      <xsl:if test="body/node()">
        <xsl:choose>
          <xsl:when test="title/@level='2'">
            <a name="{title/@id}"/>           
            <p class="title2"><xsl:value-of select="title" /></p>
          </xsl:when>
          <xsl:when test="title">
            <a name="{title/@id}"/>           
            <p class="title1"><xsl:value-of select="title" /></p>
          </xsl:when>
        </xsl:choose>
      </xsl:if>
      <xsl:apply-templates select="body[not(../title/@level='table')] | root" />   
    </xsl:when>
    
    <!-- 
      Section tables
      Only call the table-level template on the first section table found ie,
      when there are no preceding siblings that are section tables.   
    -->
    <xsl:when test="title/@level='table' and not(preceding-sibling::section/title[@level='table'])">
      <xsl:call-template name="table-level"/>
    </xsl:when>
  </xsl:choose>
</xsl:template>

<!-- 
  Create a table with all the following sibling section tables (where title/@level='table')
  and the current section.
    
  Matches 'section' elements.
 -->
<xsl:template name="table-level">
  <table class="table">
    <xsl:for-each select="following-sibling::section[title/@level='table'] | .">
    <tr> 
      <th class="hcell" width="20%"><xsl:value-of select="title" /></th>
      <td class="cell" width="80%">
        <xsl:apply-templates select="body" />   
      </td>
    </tr> 
    </xsl:for-each>  
  </table>  
</xsl:template>

  <!--
    Generates the table of Contents
  -->
  <xsl:template match="section[toc][$xsl-toc = 'true']">
    <!--
      the list of elements that needs to appear in the table of content
      in document order
    -->
    <xsl:variable name="levels" select="$titles" />
    <xsl:if test="count($levels//*[starts-with(name(),'ps:level')]) gt 0">
      <div class="toc">
        <a name="{@id}" />
        <p class="title2">Contents</p>
        <xsl:variable name="max-level" select="toc/@maxLevel" />
        <xsl:choose>
          <xsl:when test="$max-level">
            <xsl:copy-of select="psf:toc-display($levels/*[number(substring-after(name(), 'ps:level')) le number($max-level)], 1)" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:copy-of select="psf:toc-display($levels/*, 1)" />
          </xsl:otherwise>
        </xsl:choose>
      </div>
    </xsl:if>
  </xsl:template>

  <!--
    Recursive function to display all numbered headings
  -->
  <xsl:function name="psf:toc-display">
    <xsl:param name="all-levels" />
    <xsl:param name="level" as="xs:integer" />
    <!--
      process only when there are some titles with a level bigger or equal to the current level
      important otherwise it can lead to infinite recursing !!!
    -->
    <xsl:if test="count($all-levels[starts-with(name(), 'ps:level') and number(substring-after(name(), 'ps:level')) ge $level]) gt 0">
      <!-- The name of the heading element to search for -->
      <xsl:variable name="level-name" select="concat('ps:level', string($level))" />
      <ul>
        <xsl:for-each-group select="$all-levels" group-starting-with="*[name() = $level-name]">
          <xsl:variable name="title" select="current-group()[self::*[name() = $level-name]]" />
          <!--  if title of an empty section don't display it
          <xsl:if test="not(@type='title' and //section[title/@id=current()/@idref and not(body/node())])">
           -->
          <li class="toc{$level}">
            <xsl:choose>
              <xsl:when test="$title">
                <a class="toc-link{if (@comment = 'true') then ' comment' else ''}" href="#{@idref}">
                  <xsl:if test="@numbered = 'true'"><xsl:value-of select="@label" />&#160;</xsl:if>
                  <xsl:copy-of select="$title/node()" />
                </a>
                <xsl:copy-of select="psf:toc-display(current-group()[not(self::*[name() = $level-name][starts-with(name(), 'ps:level')])], $level + 1)" />
              </xsl:when>
              <xsl:otherwise>
                <xsl:copy-of select="psf:toc-display(current-group()[not(self::*[name() = $level-name][starts-with(name(), 'ps:level')])], $level + 1)" />
              </xsl:otherwise>
            </xsl:choose>
          </li>
          <!-- </xsl:if> -->
        </xsl:for-each-group>
      </ul>
    </xsl:if>
  </xsl:function>

  <xsl:template match="body">
    <xsl:variable name="type" select="concat('section-body',if (@type) then concat(' body-type-',@type) else '')" />
    <div class="{$type}">
      <xsl:if test="not(preceding::body[@id=current()/@id])">
        <a name="{@id}" />
      </xsl:if>
      <xsl:choose>
        <xsl:when test="@pageBreak='before' and not($xsl-action='preview')">
          <hr class="page-break" />
          <xsl:apply-templates />
        </xsl:when>
        <xsl:when test="@pageBreak='after' and not($xsl-action='preview')">
          <xsl:apply-templates />
          <hr class="page-break" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </div>
  </xsl:template>

  <!-- Call Anchor -->
  <xsl:template match="xref[@href and contains(@href,'.xml') and (@type='Replace' or @type='Include')]">
    <a class="xref">
      <xsl:copy-of select="@*" />
      <xsl:choose>
        <!-- addition wliem 24/7/2007 -->
        <!-- 1. when the xref I encounter equal the path to parent file, do internal linking to top of page -->
        <xsl:when test="starts-with(@href,'#psFrag')">
          <xsl:attribute name="href">
					<xsl:text>#</xsl:text>
					<xsl:value-of select="if (@frag='default') then '1' else @frag" />
				</xsl:attribute>
        </xsl:when>
        <!-- 2. when document exists somewhere in the page, do internal linking -->
        <!-- <xsl:when test="$include-xrefs/document/uriid[.=current()/@uriid][@frag='default' or @frag=current()/@frag]"> -->
        <xsl:when test="//root[@uriid=current()/@uriid]">
          <xsl:attribute name="href">
					<xsl:text>#</xsl:text>
					<xsl:value-of select="@uriid" />
					<xsl:value-of select="if (@frag='default') then '' else concat('-',@frag)" />
				</xsl:attribute>
        </xsl:when>
        <xsl:when test="@href and not(starts-with(@href,'#'))">
          <xsl:attribute name="target">_parent</xsl:attribute>
        </xsl:when>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test=".=''">
          <xsl:value-of select="@title" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </a>
  </xsl:template>

  <!-- match the rest of the xref element that has @type other than 'Replace' or 'Include'-->
  <xsl:template match="xref">
    <a class="xref">
      <xsl:attribute name="href">
        <xsl:choose>
          <!-- addition JB 29/07/2010 -->
          <!-- internal link, could be from 'replaced' section -->
          <xsl:when test="@uriid = $uriid">
            <xsl:attribute name="href">
              <xsl:text>#</xsl:text>
              <xsl:value-of select="if (@frag='default') then '1' else @frag"/>
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise><xsl:value-of select="psf:to-xref-path($siteprefix, $stylegroupname, @href)" /></xsl:otherwise>
        </xsl:choose>
		  </xsl:attribute>
      <xsl:choose>
        <xsl:when test=".=''">
          <xsl:value-of select="@title" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </a>
  </xsl:template>

	<xsl:template match="graphic">
	
	  <img>
	    <xsl:choose>
        <xsl:when test="contains(@src,'://')">
          <xsl:attribute name="src" select="@src"/>
        </xsl:when>
	      <xsl:when test="starts-with(@src,'/')">
	        <xsl:attribute name="src" select="concat('http://',$urihost,':',$uriport,@src)"/>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:variable name="uriFolder" select="substring-before($uriString,$filename)"/>
	        <xsl:attribute name="src" select="concat('http://',$urihost,':',$uriport,uriFolder,@src)"/>
	      </xsl:otherwise>
	    </xsl:choose>
	      <xsl:copy-of select="@width | @height | @alt"/>
	  </img>
	</xsl:template>

</xsl:stylesheet>