<?xml version="1.0"?>
<!--
  Templates used to ???.

  @author Jean-Baptiste Reure
  @author Christophe Lauret
  @version 17 March 2011
-->
<xsl:stylesheet version="2.0" xmlns="http://www.w3.org/1999/xhtml"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:xs="http://www.w3.org/2001/XMLSchema"
                              xmlns:psf="http://www.pageseeder.com/function"
                              exclude-result-prefixes="xs psf">

  <xsl:variable name="is-uri" select="/root/content/query/object = 'uri'"/>
  
  <!-- ant project -->
  <xsl:template match="content[@name = 'groups']" />
  <xsl:template match="content[@name = 'query']">
    <xsl:apply-templates />
  </xsl:template>
  <xsl:template match="query">
    <h2>Run script <xsl:value-of select="project/@name" /></h2>
    <input type="hidden" name="script-format" id="script-format" value="{format}" />
    <input type="hidden" name="script-owner"  id="script-owner"  value="{owner}" />
    <input type="hidden" name="script"        id="script"        value="{script}" />
    <div class="select">
      <xsl:apply-templates select="object"/>
    </div>
    <div class="select">
      <div class="title">Select task to run:</div>
      <div class="script">
        <xsl:apply-templates select="project" mode="query" />
      </div>
    </div>
    <div class="console" id="console">
      <div class="info">Script console</div>
    </div>
    <div class="button">
      <form action="{$context-path}/admin/embed/publish" id="publish-form">
        <input class="submit disabled" type="submit" name="publish" value="Run" disabled="disabled" />
      </form>
    </div>
    <script src="{$context-path}/js/plugins/jquery.psbreadcrumbbar.js"></script>
    <script src="{$context-path}/js/query.js"></script>
  </xsl:template>

  <xsl:template match="object[. = 'uri']">
    <div class="title">Select a URI to run the script on:</div>
    <div class="object">
      <div class="uri" id="uri">
        <div class="info">
          <xsl:text>The script can only run on URIs with format '</xsl:text>
          <xsl:value-of select="if (../format = '') then '(empty)' else ../format" />
          <xsl:text>' and in a group with style owner '</xsl:text>
          <xsl:value-of select="../owner" />
          <xsl:text>'.</xsl:text>
        </div>
        <div class="uri-choice-id">
          <input type="radio" id="uri-choice-id" name="uri-choice" value="id" />
          <label for="uri-choice-id">Enter URI ID</label>
          <form action="{$context-path}/admin/embed/browse/uri" method="POST" class="hidden">
            <input type="text" id="uriid" name="uriid" />
            <input type="submit" class="submit" id="search-uri" name="search" value="Search" />
          </form>
        </div>
        <div class="uri-choice-browse">
          <input type="radio" id="uri-choice-browse" name="uri-choice" value="browse" checked="checked" />
          <label for="uri-choice-browse">Browse URIs</label>
          <xsl:apply-templates select="//content[@name='groups']/ps-servlet/groups" mode="breadcrumbbar" />
        </div>
        <div class="search-result"></div>
      </div>
    </div>
  </xsl:template>
  
  <xsl:template match="object[. = 'group']">
    <div class="title">Select a group to run the script on:</div>
    <div class="object">
      <div class="group" id="group">
        <div class="info">
          <xsl:text>The script can only run on groups with style owner '</xsl:text>
          <xsl:value-of select="../owner" />
          <xsl:text>'.</xsl:text>
        </div>
        <div class="group-choice-id">
          <input type="radio" id="group-choice-id" name="group-choice" value="id" />
          <label for="group-choice-id">Enter Group ID</label>
          <form action="{$context-path}/admin/embed/browse/group" method="POST" class="hidden">
            <input type="text" id="groupid" name="groupid" />
            <input type="submit" class="submit" id="search-group" name="search" value="Search" />
          </form>
        </div>
        <div class="group-choice-browse">
          <input type="radio" id="group-choice-browse" name="group-choice" value="browse" checked="checked" />
          <label for="group-choice-browse">Browse Groups</label>
          <xsl:apply-templates select="//content[@name='groups']/ps-servlet/groups" mode="breadcrumbbar" />
        </div>
        <div class="search-result"></div>
      </div>
    </div>
  </xsl:template>
  
  <xsl:template match="project" mode="query">
    <xsl:if test="input">
      <span>Select a value for these inputs:</span>
      <div class="global-inputs">
        <xsl:apply-templates select="input" mode="display-targets" />
      </div>
    </xsl:if>
    <span>Select a target to run:</span>
    <xsl:apply-templates select="target[not(starts-with(@name,'-')) or /content/servlet/root/wo-request/xsl-targets='all']" mode="display-targets"/>
  </xsl:template>
  
  <xsl:template match="target" mode="display-targets">
    <xsl:variable name="select-multiple-targets" select="false()" />
    <div class="target">
      <input value="{@name}">
        <xsl:choose>
          <xsl:when test="$select-multiple-targets">
            <xsl:attribute name="type">checkbox</xsl:attribute>
            <xsl:attribute name="name">target-<xsl:value-of select="position()"/></xsl:attribute>
            <!--  Insert an extra field 'onclick' for show/hide the input fields -->
            <xsl:attribute name="onclick">$('#target-<xsl:value-of select="position()"/>-id').toggle();</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="type">radio</xsl:attribute>
            <xsl:attribute name="name">target-1</xsl:attribute>
            <xsl:attribute name="id">target-<xsl:value-of select="position()"/>-cb-id</xsl:attribute>
            <!--  Insert an extra field 'onclick' for show/hide the input fields -->
            <xsl:attribute name="onclick">$('.target-inputs').hide();$('#target-<xsl:value-of select="position()"/>-id').show();</xsl:attribute>
            <xsl:if test="position() = 1"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="../@default = @name or ((empty(../@default) or ../@default = '') and position() = 1)">
          <xsl:attribute name="checked">true</xsl:attribute>
        </xsl:if>
      </input>
      <span class="target-title">
        <xsl:choose>
          <xsl:when test="@description"><xsl:value-of select="@description" /></xsl:when>
          <xsl:otherwise>Target <xsl:value-of select="@name" /></xsl:otherwise>
        </xsl:choose>
      </span>
      
      <!--  add a unique id for hiding -->
      <div class="target-inputs" id="target-{position()}-id">
        <xsl:choose>
          <xsl:when test="../@default = @name">
            <xsl:attribute name="style">display:block;</xsl:attribute>
          </xsl:when>
          <xsl:when test="(empty(../@default) or ../@default = '') and position() = 1">
            <xsl:attribute name="style">display:block;</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="style">display:none;</xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="input" mode="display-targets" />
        <xsl:apply-templates select="antcall" mode="display-targets" />
      </div>
    </div>
  </xsl:template>
  
  <xsl:template match="input" mode="display-targets">
    <div class="input-message">
      <xsl:choose>
        <xsl:when test="@validargs = 'true,false' or @validargs = 'false,true'">
          <input class="checkbox" type="checkbox" name="input-value-{count(preceding::input)}" value="true">
            <xsl:if test="@defaultvalue = 'true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
          </input>
          <label>
            <input type="hidden" name="input-message-{count(preceding::input)}" value="{@message}" />
            <xsl:value-of select="@message"/>
            <xsl:text> </xsl:text>
          </label>
        </xsl:when>
        <xsl:when test="@validargs">
          <label>
            <input type="hidden" name="input-message-{count(preceding::input)}" value="{@message}" />
            <xsl:value-of select="@message"/>
            <xsl:text> </xsl:text>
          </label>
          <select class="select" name="input-value-{count(preceding::input)}">
            <xsl:variable name="default-value" select="@defaultvalue" />
            <xsl:for-each select="tokenize(@validargs,',')">
              <option value="{.}">
                <xsl:if test=".=$default-value"><xsl:attribute name="selected">true</xsl:attribute></xsl:if>
                <xsl:value-of select="."/>
              </option>
            </xsl:for-each>
          </select>
        </xsl:when>
        <xsl:otherwise>
          <label>
            <input type="hidden" name="input-message-{count(preceding::input)}" value="{@message}" />
            <xsl:value-of select="@message"/>
            <xsl:text> </xsl:text>
          </label>
          <!--  check whether the input field is a password field -->
          <xsl:choose>
            <xsl:when test="contains(@message,'password')">
              <input class="textbox" type="password" name="input-value-{count(preceding::input)}" value="{@defaultvalue}" autocomplete="off" />
            </xsl:when>
            <xsl:otherwise>
              <input class="textbox" type="text" name="input-value-{count(preceding::input)}" value="{@defaultvalue}" />
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    </div>
  </xsl:template>
  
  <!-- ++++++++++++++++++++++++++++++ Breadcrumb Bar ++++++++++++++++++++++++++++++++++++++++++++++++++ -->
  <xsl:template match="groups" mode="breadcrumbbar">
    <xsl:variable name="siteprefix" select="../../siteprefix" />
    <div class="ps-bcb">
      <div class="ps-bcb-breadcrumb">
        <a class="ps-bcb-delim" href="#">&#187;</a>
        <a class="ps-bcb-item" href="#" nodeid="" nodepath="" nodetype="group">&#160;</a>
        <div class="ps-bcb-items">
          <ul class="ps-bcb-items-list">
            <xsl:for-each select="group">
              <xsl:sort select="name" />
              <xsl:variable name="defaultpath" select="concat($siteprefix, '/', translate(name, '-', '/'), '/*')" />
              <xsl:variable name="defaultguri" select="groupuris/groupuri[path = $defaultpath]" />
              <xsl:if test="not(empty($defaultguri)) or not($is-uri)">
                <li><a nodeid="{id}" nodepath="{name}" nodetype="group" class="ps-bcb-items-list-item"
                       href="{if ($is-uri) then concat($context-path, '/admin/embed/browse/uris?guri=', $defaultguri[1]/id) else '#'}">
                      <xsl:value-of select="name" />
                </a></li>
              </xsl:if>
            </xsl:for-each>
          </ul>
        </div>
      </div>
      <div class="loading hidden"><span>Loading...</span></div>
   </div>
  </xsl:template>

</xsl:stylesheet>
